[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - pygeodesy.auxilats.auxDST.AuxDST: Discrete Sine Transforms (DST) for Auxiliary latitudes.
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.AttributeError: Attribute not found.
          - pygeodesy.lazily.LazyAttributeError: Raised if a `lazily imported` attribute is missing or invalid.
        - exceptions.ImportError: Import can't find module, or can't find name in module.
          - pygeodesy.lazily.LazyImportError: Raised if `lazy import` is not supported, disabled or failed.
        - exceptions.ValueError: Inappropriate argument value (of correct type).
          - pygeodesy.errors._ValueError: (INTERNAL) Format a `ValueError` with/-out exception chaining.
            - pygeodesy.albers.AlbersError: An AlbersEqualArea, AlbersEqualArea2, AlbersEqualArea4, AlbersEqualAreaCylindrical, AlbersEqualAreaNorth, AlbersEqualAreaSouth or Albers7Tuple issue.
            - pygeodesy.ltp.AttitudeError: An Attitude or Attitude4Tuple issue.
            - pygeodesy.errors.AuxError: Error raised for a rhumb.aux_, `Aux`, `AuxDLat` or `AuxLat` issue.
            - pygeodesy.azimuthal.AzimuthalError: An azimuthal Equidistant, EquidistantKarney, Gnomonic, LambertEqualArea, Orthographic, Stereographic or Azimuthal7Tuple issue.
            - pygeodesy.css.CSSError: Cassini-Soldner (CSS) conversion or other Css issue.
            - pygeodesy.errors.ClipError: Clip box or clip region issue.
            - pygeodesy.errors.CrossError: Error raised for zero or near-zero vectorial cross products, occurring for coincident or colinear points, lines or bearings.
            - pygeodesy.epsg.EPSGError: EPSG encode, decode or other Epsg issue.
            - pygeodesy.ecef.EcefError: An ECEF or `Ecef*` related issue.
            - pygeodesy.ellipses.EllipseError: Raised for any Ellipse or `ellipses` issue.
            - pygeodesy.elliptic.EllipticError: Elliptic function, integral, convergence or other Elliptic issue.
            - pygeodesy.gars.GARSError: Global Area Reference System (GARS) encode, decode or other Garef issue.
            - pygeodesy.errors.GeodesicError: Error raised for convergence or other issues in geodesicx, geodesicw, geodsolve or karney.
              - pygeodesy.geod3solve.Geodesic3Error: Error raised for issues in geod3solve.
            - pygeodesy.geohash.GeohashError: Geohash encode, decode or other Geohash issue.
            - pygeodesy.errors.IntersectionError: Error raised for line or circle intersection issues.
            - pygeodesy.ktm.KTMError: Error raised for KTransverseMercator and KTransverseMercator.forward issues.
            - pygeodesy.lcc.LCCError: Lambert Conformal Conic `LCC` or other Lcc issue.
            - pygeodesy.errors.LenError: Error raised for mis-matching `len` values.
            - pygeodesy.errors.LimitError: Error raised for lat- or longitudinal values or deltas exceeding the given `limit` in functions equirectangular, equirectangular4, `nearestOn*` and `simplify*` or methods with `limit` or `options` keyword arguments.
              - pygeodesy.errors.UnitError: Default exception for units issues for a value exceeding the `low` or `high` limit.
            - pygeodesy.ltp.LocalError: A LocalCartesian or Ltp related issue.
            - pygeodesy.errors.MGRSError: Military Grid Reference System (MGRS) parse or other Mgrs issue.
            - pygeodesy.errors.NumPyError: Error raised for `NumPy` issues.
            - pygeodesy.osgr.OSGRError: Error raised for a parseOSGR, Osgr or other OSGR issue.
            - pygeodesy.errors.ParseError: Error parsing degrees, radians or several other formats.
            - pygeodesy.errors.PointsError: Error for an insufficient number of points.
              - pygeodesy.frechet.FrechetError: Fréchet issue.
              - pygeodesy.hausdorff.HausdorffError: Hausdorff issue.
              - pygeodesy.heights.HeightError: Height interpolator `Height...` or interpolation issue.
                - pygeodesy.geoids.GeoidError: Geoid interpolator `Geoid...` or interpolation issue.
                  - pygeodesy.geoids.PGMError: An issue while parsing or cropping an `egm*.pgm` geoid dataset.
              - pygeodesy.errors.SciPyError: Error raised for `SciPy` issues.
              - pygeodesy.errors.SciPyWarning: Error thrown for `SciPy` warnings.
            - pygeodesy.errors.RangeError: Error raised for lat- or longitude values outside the `clip`, `clipLat`, `clipLon` in functions parse3llh, parseDMS, parseDMS2 and parseRad or the `limit` set with functions clipDegrees and clipRadians.
            - pygeodesy.resections.ResectionError: Error raised for issues in pygeodesy.resections.
            - pygeodesy.fsums.ResidualError: Error raised for a division, power or root operation of an Fsum instance with a `residual` ratio exceeding the RESIDUAL threshold.
            - pygeodesy.errors.RhumbError: Error raised for a rhumb aux_, ekx or solve issue.
            - pygeodesy.errors.TRFError: Terrestrial Reference Frame (TRF), Epoch, RefFrame or RefFrame conversion issue.
            - pygeodesy.errors.TriangleError: Error raised for triangle, intersection or resection issues.
            - pygeodesy.triaxials.bases.TriaxialError: Raised for any triaxial issue.
            - pygeodesy.ups.UPSError: Universal Polar Stereographic (UPS) parse or other Ups issue.
            - pygeodesy.utm.UTMError: Universal Transverse Mercator (UTM parse or other Utm issue.
              - pygeodesy.etm.ETMError: Exact Transverse Mercator (ETM) parse, projection or other Etm issue or ExactTransverseMercator conversion failure.
            - pygeodesy.utmups.UTMUPSError: Universal Transverse Mercator/Universal Polar Stereographic (UTM/UPS) parse, validate or other issue.
            - pygeodesy.errors.VectorError: Vector3d, `Cartesian*` or `*Nvector` issues.
            - pygeodesy.ellipsoidalVincenty.VincentyError: Error raised by Vincenty's `Direct` and `Inverse` methods for coincident points or lack of convergence.
            - pygeodesy.wgrs.WGRSError: World Geographic Reference System (WGRS) encode, decode or other Georef issue.
            - pygeodesy.webmercator.WebMercatorError: Web Mercator (WM) parser or Wm issue.
  - pygeodesy.karney.Caps: Enum-style masks to be bit-`or`'ed to specify `geodesic`, `rhumb` or `-lines` capabilities (`caps`) and method results (`outmask`).
  - _abcoll.Container
    - _abcoll.Sequence: All the operations on a read-only sequence.
      - pygeodesy.points._Basequence: (INTERNAL) Base class.
        - pygeodesy.points.LatLon2psxy: Wrapper for `LatLon` points as "on-the-fly" pseudo-xy coordinates.
        - pygeodesy.points._Array2LatLon: (INTERNAL) Base class for Numpy2LatLon or Tuple2LatLon.
          - pygeodesy.points.Numpy2LatLon: Wrapper for `NumPy` arrays as "on-the-fly" `LatLon` points.
          - pygeodesy.points.Tuple2LatLon: Wrapper for tuple sequences as "on-the-fly" `LatLon` points.
  - pygeodesy.props.DeprecationWarnings: (INTERNAL) Handle `DeprecationWaring`s.
  - pygeodesy.deprecated.consterns.Elliperim: DEPRECATED on 2026.02.06, use class Ellipse.
  - pygeodesy.geohash.Geohashed: A cache of en- and decoded geohashes of one precision.
  - _abcoll.Iterable
    - _abcoll.Sequence: All the operations on a read-only sequence.
      - pygeodesy.points._Basequence: (INTERNAL) Base class.
        - pygeodesy.points.LatLon2psxy: Wrapper for `LatLon` points as "on-the-fly" pseudo-xy coordinates.
        - pygeodesy.points._Array2LatLon: (INTERNAL) Base class for Numpy2LatLon or Tuple2LatLon.
          - pygeodesy.points.Numpy2LatLon: Wrapper for `NumPy` arrays as "on-the-fly" `LatLon` points.
          - pygeodesy.points.Tuple2LatLon: Wrapper for tuple sequences as "on-the-fly" `LatLon` points.
  - pygeodesy.triaxials.bases.LLK: Enum-like `Lat-/Longitude Kinds (LLK)`, see coord.
  - _abcoll.Sized
    - _abcoll.Sequence: All the operations on a read-only sequence.
      - pygeodesy.points._Basequence: (INTERNAL) Base class.
        - pygeodesy.points.LatLon2psxy: Wrapper for `LatLon` points as "on-the-fly" pseudo-xy coordinates.
        - pygeodesy.points._Array2LatLon: (INTERNAL) Base class for Numpy2LatLon or Tuple2LatLon.
          - pygeodesy.points.Numpy2LatLon: Wrapper for `NumPy` arrays as "on-the-fly" `LatLon` points.
          - pygeodesy.points.Tuple2LatLon: Wrapper for tuple sequences as "on-the-fly" `LatLon` points.
  - pygeodesy.booleans._BooleanBase
    - pygeodesy.booleans.BooleanFHP: Composite class providing boolean operations between two composites using Forster-Hormann-Popa's C++ implementation, transcoded to pure Python.
    - pygeodesy.booleans.BooleanGH: Composite class providing boolean operations between two composites using the Greiner-Hormann algorithm, extended.
  - pygeodesy.ltp._ChLV: (INTERNAL) Base class for `ChLV*` classes.
    - pygeodesy.ltp.ChLV: Conversion between WGS84 geodetic and Swiss projection coordinates using pygeodesy.EcefKarney's Earth-Centered, Earth-Fixed (ECEF) methods.
    - pygeodesy.ltp.ChLVa: Conversion between WGS84 geodetic and Swiss projection coordinates using the Approximate formulas, page 13.
    - pygeodesy.ltp.ChLVe: Conversion between WGS84 geodetic and Swiss projection coordinates using the Ellipsoidal approximate formulas, pp 10-11 and Bolliger, J. pp 148-151 (also GGGS).
  - pygeodesy.namedTuples._Convergence: (INTERNAL) DEPRECATED Property `convergence`, use property `gamma`.
    - pygeodesy.namedTuples.Forward4Tuple: 4-Tuple `(easting, northing, gamma, scale)` in `meter`, `meter`, meridian convergence `gamma` at point in `degrees` and the `scale` of projection at point `scalar`.
    - pygeodesy.namedTuples.LatLonDatum5Tuple: 5-Tuple `(lat, lon, datum, gamma, scale)` in `degrees90`, `degrees180`, Datum, `degrees` and `float`.
    - pygeodesy.namedTuples.Reverse4Tuple: 4-Tuple `(lat, lon, gamma, scale)` with `lat`- and `lon`gitude in `degrees`, meridian convergence `gamma` at point in `degrees` and the `scale` of projection at point `scalar`.
    - pygeodesy.namedTuples.UtmUps8Tuple: 8-Tuple `(zone, hemipole, easting, northing, band, datum, gamma, scale)` as `int`, `str`, `meter`, `meter`, `band` letter, `Datum`, `degrees` and `scalar`, where `zone` is `1..60` for UTM or `0` for UPS, `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole and `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'`.
  - pygeodesy.named._Named: (INTERNAL) Root class for named objects.
    - pygeodesy.angles.Ang: An accurate representation of angles, as 3-tuple `(s, c, n)`.
    - pygeodesy.auxilats.auxAngle.AuxAngle: An accurate representation of angles
      - pygeodesy.auxilats.auxAngle.AuxBeta: A Parametric, Auxiliary latitude.
      - pygeodesy.auxilats.auxAngle.AuxChi: A Conformal, Auxiliary latitude.
      - pygeodesy.auxilats.auxLat.AuxLat: Base class for accurate conversion between Auxiliary latitudes on an ellipsoid.
        - pygeodesy.auxilats.auxDLat.AuxDLat: Class to compute `Divided Differences` of Auxiliary latitudes and other `Divided Differences` needed for RhumbAux and RhumbLineAux calculations.
      - pygeodesy.auxilats.auxAngle.AuxMu: A Rectifying, Auxiliary latitude.
      - pygeodesy.auxilats.auxAngle.AuxPhi: A Geodetic or Geographic, Auxiliary latitude.
      - pygeodesy.auxilats.auxAngle.AuxTheta: A Geocentric, Auxiliary latitude.
      - pygeodesy.auxilats.auxAngle.AuxXi: An Authalic, Auxiliary latitude.
    - pygeodesy.elliptic.Elliptic: Elliptic integrals and functions.
    - pygeodesy.frechet.Frechet: Frechet base class, requires method Frechet.distance to be overloaded.
      - pygeodesy.frechet.FrechetDegrees: DEPRECATED, use an other `Frechet*` class.
      - pygeodesy.frechet.FrechetDistanceTo: Compute the `Frechet` distance with the point1s' `LatLon.distanceTo` method.
      - pygeodesy.frechet.FrechetEquirectangular: Compute the `Frechet` distance with function pygeodesy.equirectangular.
      - pygeodesy.frechet.FrechetExact: Compute the `Frechet` distance with method GeodesicExact`.Inverse`.
      - pygeodesy.frechet.FrechetKarney: Compute the `Frechet` distance with Karney's geographiclib geodesic.Geodesic`.Inverse` method.
      - pygeodesy.frechet.FrechetRadians: DEPRECATED, use an other `Frechet*` class.
      - pygeodesy.frechet._FrechetMeterRadians: (INTERNAL) Returning `meter` or `radians` depending on the optional keyword arguments supplied at instantiation of the `Frechet*` sub-class.
        - pygeodesy.frechet.FrechetCosineLaw: Compute the `Frechet` distance with functionn pygeodesy.cosineLaw.
        - pygeodesy.frechet.FrechetEuclidean: Compute the `Frechet` distance with function pygeodesy.euclidean.
        - pygeodesy.frechet.FrechetFlatLocal: Compute the `Frechet` distance with function pygeodesy.flatLocal_/pygeodesy.hubeny.
          - pygeodesy.frechet.FrechetHubeny: Compute the `Frechet` distance with function pygeodesy.flatLocal_/pygeodesy.hubeny.
        - pygeodesy.frechet.FrechetFlatPolar: Compute the `Frechet` distance with function flatPolar_.
        - pygeodesy.frechet.FrechetHaversine: Compute the `Frechet` distance with function pygeodesy.haversine_.
        - pygeodesy.frechet.FrechetThomas: Compute the `Frechet` distance with function pygeodesy.thomas_.
        - pygeodesy.frechet.FrechetVincentys: Compute the `Frechet` distance with function pygeodesy.vincentys_.
    - pygeodesy.fsums.Fsum: Precision floating point summation, running summation and accurate multiplication.
      - pygeodesy.fmath.Fdot: Precision dot product.
        - pygeodesy.fmath.Fdot_: Precision dot product.
      - pygeodesy.fmath.Fhorner: Precision polynomial evaluation using the Horner form.
      - pygeodesy.fmath.Fhypot: Precision summation and hypotenuse, default `root=2`.
      - pygeodesy.fmath.Fpolynomial: Precision polynomial evaluation.
      - pygeodesy.fmath.Fpowers: Precision summation of powers, optimized for `power=2, 3 and 4`.
      - pygeodesy.fmath.Froot: The root of a precision summation.
        - pygeodesy.fmath.Fcbrt: Cubic root of a precision summation.
        - pygeodesy.fmath.Fsqrt: Square root of a precision summation.
    - pygeodesy.hausdorff.Hausdorff: Hausdorff base class, requires method Hausdorff.distance to be overloaded.
      - pygeodesy.hausdorff.HausdorffDegrees: Hausdorff base class for distances from `LatLon` points in `degrees`.
      - pygeodesy.hausdorff.HausdorffDistanceTo: Compute the `Hausdorff` distance the points' `LatLon.distanceTo` method.
      - pygeodesy.hausdorff.HausdorffEquirectangular: Compute the `Hausdorff` distance with function pygeodesy.equirectangular.
      - pygeodesy.hausdorff.HausdorffExact: Compute the `Hausdorff` distance with method GeodesicExact`.Inverse`.
      - pygeodesy.hausdorff.HausdorffKarney: Compute the `Hausdorff` distance with Karney's geographiclib geodesic.Geodesic`.Inverse` method.
      - pygeodesy.hausdorff.HausdorffRadians: Hausdorff base class for distances from `LatLon` points converted from `degrees` to `radians`.
      - pygeodesy.hausdorff._HausdorffMeterRadians: (INTERNAL) Returning `meter` or `radians` depending on the optional keyword arguments supplied at instantiation of the `Hausdorff*` sub-class.
        - pygeodesy.hausdorff.HausdorffCosineLaw: Compute the `Hausdorff` distance with function pygeodesy.cosineLaw_.
        - pygeodesy.hausdorff.HausdorffEuclidean: Compute the `Hausdorff` distance with function pygeodesy.euclidean_.
        - pygeodesy.hausdorff.HausdorffFlatLocal: Compute the `Hausdorff` distance with function pygeodesy.flatLocal_/pygeodesy.hubeny_.
          - pygeodesy.hausdorff.HausdorffHubeny: Compute the `Hausdorff` distance with function pygeodesy.flatLocal_/pygeodesy.hubeny_.
        - pygeodesy.hausdorff.HausdorffFlatPolar: Compute the `Hausdorff` distance with function pygeodesy.flatPolar_.
        - pygeodesy.hausdorff.HausdorffHaversine: Compute the `Hausdorff` distance with function pygeodesy.haversine_.
        - pygeodesy.hausdorff.HausdorffThomas: Compute the `Hausdorff` distance with function pygeodesy.thomas_.
        - pygeodesy.hausdorff.HausdorffVincentys: Compute the `Hausdorff` distance with function pygeodesy.vincentys_.
    - pygeodesy.trf.TRFXform: A Terrestrial Reference Frame (TRF) converter between two reference frames observed at an `epoch`.
    - pygeodesy.iters._BaseIter: (INTERNAL) Iterator over items with loop-back and de-duplication.
      - pygeodesy.iters.PointsIter: Iterator for `points` with optional loop-back and copies.
        - pygeodesy.iters.LatLon2PsxyIter: Iterate and convert for `points` with optional loop-back and copies.
    - pygeodesy.booleans._Clip: (INTERNAL) A doubly-linked list representing a closed polygon of LatLonFHP or LatLonGH points, duplicates and intersections with other clips.
    - pygeodesy.booleans._CompositeBase: (INTERNAL) Base class for BooleanFHP and BooleanGH (`_CompositeFHP` and `_CompositeGH`).
      - pygeodesy.booleans._CompositeFHP: (INTERNAL) A list of clips representing a composite of LatLonFHP points, duplicates and intersections with an other composite.
        - pygeodesy.booleans.BooleanFHP: Composite class providing boolean operations between two composites using Forster-Hormann-Popa's C++ implementation, transcoded to pure Python.
      - pygeodesy.booleans._CompositeGH: (INTERNAL) A list of clips representing a composite of LatLonGH points, duplicates and intersections with an other composite.
        - pygeodesy.booleans.BooleanGH: Composite class providing boolean operations between two composites using the Greiner-Hormann algorithm, extended.
    - pygeodesy.ecefLocals._EcefLocal: (INTERNAL) Base class for `CartesianBase`, `Ecef9Tuple` and `LatLonBase`, providing ECEF to local coordinate conversions.
      - pygeodesy.cartesianBase.CartesianBase: (INTERNAL) Base class for ellipsoidal and spherical `Cartesian`.
        - pygeodesy.ellipsoidalBase.CartesianEllipsoidalBase: (INTERNAL) Base class for ellipsoidal `Cartesian`s.
          - pygeodesy.ellipsoidalExact.Cartesian: Extended to convert exact Cartesian to exact LatLon points.
          - pygeodesy.ellipsoidalGeodSolve.Cartesian: Extended to convert exact Cartesian to exact LatLon points.
          - pygeodesy.ellipsoidalVincenty.Cartesian: Extended to convert geocentric, Cartesian points to Vincenty-based, ellipsoidal, geodetic LatLon.
          - pygeodesy.ellipsoidalNvector.Cartesian: Extended to convert geocentric, Cartesian points to `Nvector` and n-vector-based, geodetic LatLon.
          - pygeodesy.ellipsoidalKarney.Cartesian: Extended to convert `Karney`-based Cartesian to `Karney`-based LatLon points.
        - pygeodesy.sphericalBase.CartesianSphericalBase: (INTERNAL) Base class for spherical `Cartesian`s.
          - pygeodesy.sphericalNvector.Cartesian: Extended to convert geocentric, Cartesian points to `Nvector` and n-vector-based, spherical LatLon.
          - pygeodesy.sphericalTrigonometry.Cartesian: Extended to convert geocentric, Cartesian points to spherical, geodetic LatLon.
      - pygeodesy.ecef.Ecef9Tuple: 9-Tuple `(x, y, z, lat, lon, height, C, M, datum)` with geocentric `x`, `y` and `z` plus geodetic `lat`, `lon` and `height`, case `C` and optionally, rotation matrix `M` (EcefMatrix) and `datum`, with `lat` and `lon` in `degrees` and `x`, `y`, `z` and `height` in `meter`, conventionally.
      - pygeodesy.latlonBase.LatLonBase: (INTERNAL) Base class for ellipsoidal and spherical `satLon`s.
        - pygeodesy.ellipsoidalBase.LatLonEllipsoidalBase: (INTERNAL) Base class for ellipsoidal `LatLon`s.
          - pygeodesy.ellipsoidalNvector.LatLon: An n-vector-based, ellipsoidal LatLon point.
          - pygeodesy.ellipsoidalBaseDI.LatLonEllipsoidalBaseDI: (INTERNAL) Base class for `ellipsoidal*.LatLon` classes with overloaded `Direct` and `Inverse` methods.
            - pygeodesy.ellipsoidalExact.LatLon: An ellipsoidal LatLon like ellipsoidalKarney.LatLon but using exact geodesic classes GeodesicExact and GeodesicLineExact to compute geodesic distances, bearings (azimuths), etc.
            - pygeodesy.ellipsoidalGeodSolve.LatLon: An ellipsoidal LatLon like ellipsoidalKarney.LatLon but using (exact) geodesic wrapper GeodesicSolve to compute the geodesic distance, initial and final bearing (azimuths) between two given points or the destination point given a start point and an (initial) bearing.
            - pygeodesy.ellipsoidalKarney.LatLon: An ellipsoidal LatLon similar to ellipsoidalVincenty.LatLon but using Karney's Python geographiclib to compute geodesic distances, bearings (azimuths), etc.
            - pygeodesy.ellipsoidalVincenty.LatLon: New point on an (oblate) ellipsoidal earth model, using the formulae devised by Thaddeus Vincenty (1975) to compute geodesic distances, bearings (azimuths), etc.
        - pygeodesy.deprecated.bases.LatLonHeightBase: DEPRECATED on 2021.02.10, use (INTERNAL) class pygeodesy.latlonBase.LatLonBase.
        - pygeodesy.nvectorBase.LatLonNvectorBase: (INTERNAL) Base class for n-vector-based ellipsoidal and spherical `LatLon`s.
          - pygeodesy.ellipsoidalNvector.LatLon: An n-vector-based, ellipsoidal LatLon point.
          - pygeodesy.sphericalNvector.LatLon: New n-vector-based point on a spherical earth model.
        - pygeodesy.sphericalBase.LatLonSphericalBase: (INTERNAL) Base class for spherical `LatLon`s.
          - pygeodesy.sphericalNvector.LatLon: New n-vector-based point on a spherical earth model.
          - pygeodesy.sphericalTrigonometry.LatLon: New point on a spherical earth model, based on trigonometry formulae.
        - pygeodesy.points.LatLon_: Low-overhead `LatLon` class, mainly for Numpy2LatLon and Tuple2LatLon.
    - pygeodesy.fstats._FstatsNamed: (INTERNAL) Base class.
      - pygeodesy.fstats.Flinear: Cook's `RunningRegression` computing the running slope, intercept and correlation of a linear regression.
      - pygeodesy.fstats._FstatsBase: (INTERNAL) Base running stats class.
        - pygeodesy.fstats.Fcook: Cook's `RunningStats` computing the running mean, median and (sample) kurtosis, skewness, variance, standard deviation and Jarque-Bera normality.
        - pygeodesy.fstats.Fwelford: Welford's accumulator computing the running mean, (sample) variance and standard deviation.
    - pygeodesy.heights._HeightNamed: (INTERNAL) Interpolator base class.
      - pygeodesy.heights._HeightBase: (INTERNAL) Interpolator base class.
        - pygeodesy.heights.HeightCubic: Height interpolator based on `SciPy` interp2d `kind='cubic'` or bisplrep/-ev `kx=ky=3`.
          - pygeodesy.heights.HeightLinear: Height interpolator based on `SciPy` interp2d `kind='linear'` or bisplrep/-ev `kx=ky=1`.
        - pygeodesy.heights.HeightLSQBiSpline: Height interpolator using `SciPy` LSQSphereBivariateSpline.
        - pygeodesy.heights.HeightSmoothBiSpline: Height interpolator using `SciPy` SmoothSphereBivariateSpline.
        - pygeodesy.geoids._GeoidBase: (INTERNAL) Base class for `Geoid...`s.
          - pygeodesy.geoids.GeoidEGM96: Geoid height interpolator for the EGM96 15 Minute Interpolation Grid based on `SciPy` interpolation RectBivariateSpline, interp2d or bisplrep/-ev.
          - pygeodesy.geoids.GeoidG2012B: Geoid height interpolator for GEOID12B Model grids CONUS, Alaska, Hawaii, Guam and Northern Mariana Islands, Puerto Rico and U.S. Virgin Islands and American Samoa based on `SciPy` interpolation RectBivariateSpline, interp2d or bisplrep/-ev.
          - pygeodesy.geoids.GeoidKarney: Geoid height interpolator for Karney's GeographicLib Earth Gravitational Model (EGM) geoid egm*.pgm datasets using bilinear or cubic interpolation and caching in pure Python, transcoded from Karney's C++ class Geoid.
          - pygeodesy.geoids.GeoidPGM: Geoid height interpolator for Karney's GeographicLib Earth Gravitational Model (EGM) geoid egm*.pgm datasets but based on `SciPy` RectBivariateSpline, bisplrep/-ev or interp2d interpolation.
      - pygeodesy.heights._HeightIDW: (INTERNAL) Base class for Inverse Distance Weighting (IDW) height interpolators.
        - pygeodesy.heights.HeightIDWcosineLaw: Height interpolator using Inverse Distance Weighting (IDW) and function pygeodesy.cosineLaw.
        - pygeodesy.heights.HeightIDWdistanceTo: Height interpolator using Inverse Distance Weighting (IDW) and the points' `LatLon.distanceTo` method.
        - pygeodesy.heights.HeightIDWequirectangular: Height interpolator using Inverse Distance Weighting (IDW) and function pygeodesy.equirectangular4.
        - pygeodesy.heights.HeightIDWeuclidean: Height interpolator using Inverse Distance Weighting (IDW) and function pygeodesy.euclidean_.
        - pygeodesy.heights.HeightIDWexact: Height interpolator using Inverse Distance Weighting (IDW) and method GeodesicExact.Inverse.
        - pygeodesy.heights.HeightIDWflatLocal: Height interpolator using Inverse Distance Weighting (IDW) and the function pygeodesy.flatLocal_/pygeodesy.hubeny_.
          - pygeodesy.heights.HeightIDWhubeny: Height interpolator using Inverse Distance Weighting (IDW) and the function pygeodesy.flatLocal_/pygeodesy.hubeny_.
        - pygeodesy.heights.HeightIDWflatPolar: Height interpolator using Inverse Distance Weighting (IDW) and function pygeodesy.flatPolar_.
        - pygeodesy.heights.HeightIDWhaversine: Height interpolator using Inverse Distance Weighting (IDW) and function pygeodesy.haversine_.
        - pygeodesy.heights.HeightIDWkarney: Height interpolator using Inverse Distance Weighting (IDW) and Karney's geographiclib method geodesic.Geodesic.Inverse.
        - pygeodesy.heights.HeightIDWthomas: Height interpolator using Inverse Distance Weighting (IDW) and function pygeodesy.thomas_.
        - pygeodesy.heights.HeightIDWvincentys: Height interpolator using Inverse Distance Weighting (IDW) and function pygeodesy.vincentys_.
    - pygeodesy.booleans._LatLonBool: (INTERNAL) Base class for LatLonFHP and LatLonGH.
      - pygeodesy.booleans.LatLonFHP: A point or intersection in a BooleanFHP clip or composite.
      - pygeodesy.booleans.LatLonGH: A point or intersection in a BooleanGH clip or composite.
    - pygeodesy.named._NamedBase: (INTERNAL) Base class with name.
      - pygeodesy.ltp.Attitude: The pose of a plane or camera in space.
      - pygeodesy.css.CassiniSoldner: Cassini-Soldner projection, a Python version of Karney's C++ class CassiniSoldner.
      - pygeodesy.css.Css: Cassini-Soldner East-/Northing location.
      - pygeodesy.ellipses.Ellipse: Class to compute various attributes of a 2-D ellipse.
      - pygeodesy.etm.ExactTransverseMercator: Pure Python version of Karney's C++ class TransverseMercatorExact, a numerically exact transverse Mercator projection, abbreviated as `TMExact`.
      - pygeodesy.ltp.Frustum: A rectangular pyramid, typically representing a camera's field-of-view (fov) and the intersection with (or projection to) a local tangent plane.
      - pygeodesy.geodesicx.gxarea.GeodesicAreaExact: Area and perimeter of a geodesic polygon, an enhanced version of Karney's Python class PolygonArea using the more accurate surface area.
        - pygeodesy.geodesicx.gxarea.PolygonArea: For `geographiclib` compatibility, sub-class of GeodesicAreaExact.
      - pygeodesy.ktm.KTransverseMercator: Karney's C++ class TransverseMercator transcoded to pure Python, following is a partial copy of Karney's documentation.
      - pygeodesy.latlonBase.LatLonBase: (INTERNAL) Base class for ellipsoidal and spherical `satLon`s.
        - pygeodesy.ellipsoidalBase.LatLonEllipsoidalBase: (INTERNAL) Base class for ellipsoidal `LatLon`s.
          - pygeodesy.ellipsoidalNvector.LatLon: An n-vector-based, ellipsoidal LatLon point.
          - pygeodesy.ellipsoidalBaseDI.LatLonEllipsoidalBaseDI: (INTERNAL) Base class for `ellipsoidal*.LatLon` classes with overloaded `Direct` and `Inverse` methods.
            - pygeodesy.ellipsoidalExact.LatLon: An ellipsoidal LatLon like ellipsoidalKarney.LatLon but using exact geodesic classes GeodesicExact and GeodesicLineExact to compute geodesic distances, bearings (azimuths), etc.
            - pygeodesy.ellipsoidalGeodSolve.LatLon: An ellipsoidal LatLon like ellipsoidalKarney.LatLon but using (exact) geodesic wrapper GeodesicSolve to compute the geodesic distance, initial and final bearing (azimuths) between two given points or the destination point given a start point and an (initial) bearing.
            - pygeodesy.ellipsoidalKarney.LatLon: An ellipsoidal LatLon similar to ellipsoidalVincenty.LatLon but using Karney's Python geographiclib to compute geodesic distances, bearings (azimuths), etc.
            - pygeodesy.ellipsoidalVincenty.LatLon: New point on an (oblate) ellipsoidal earth model, using the formulae devised by Thaddeus Vincenty (1975) to compute geodesic distances, bearings (azimuths), etc.
        - pygeodesy.deprecated.bases.LatLonHeightBase: DEPRECATED on 2021.02.10, use (INTERNAL) class pygeodesy.latlonBase.LatLonBase.
        - pygeodesy.nvectorBase.LatLonNvectorBase: (INTERNAL) Base class for n-vector-based ellipsoidal and spherical `LatLon`s.
          - pygeodesy.ellipsoidalNvector.LatLon: An n-vector-based, ellipsoidal LatLon point.
          - pygeodesy.sphericalNvector.LatLon: New n-vector-based point on a spherical earth model.
        - pygeodesy.sphericalBase.LatLonSphericalBase: (INTERNAL) Base class for spherical `LatLon`s.
          - pygeodesy.sphericalNvector.LatLon: New n-vector-based point on a spherical earth model.
          - pygeodesy.sphericalTrigonometry.LatLon: New point on a spherical earth model, based on trigonometry formulae.
        - pygeodesy.points.LatLon_: Low-overhead `LatLon` class, mainly for Numpy2LatLon and Tuple2LatLon.
      - pygeodesy.lcc.Lcc: Lambert conformal conic East-/Northing location.
      - pygeodesy.ltp.LocalCartesian: Conversion between geodetic `(lat, lon, height)` and local cartesian `(x, y, z)` coordinates with geodetic origin `(lat0, lon0, height0)`, transcoded from Karney's C++ class LocalCartesian.
        - pygeodesy.ltp.ChLVa: Conversion between WGS84 geodetic and Swiss projection coordinates using the Approximate formulas, page 13.
        - pygeodesy.ltp.ChLVe: Conversion between WGS84 geodetic and Swiss projection coordinates using the Ellipsoidal approximate formulas, pp 10-11 and Bolliger, J. pp 148-151 (also GGGS).
        - pygeodesy.ltp.Ltp: A local tangent plan (LTP), a sub-class of `LocalCartesian` with (re-)configurable ECEF converter.
          - pygeodesy.ltp.ChLV: Conversion between WGS84 geodetic and Swiss projection coordinates using pygeodesy.EcefKarney's Earth-Centered, Earth-Fixed (ECEF) methods.
      - pygeodesy.mgrs.Mgrs: Military Grid Reference System (MGRS/NATO) references, with method to convert to UTM coordinates.
      - pygeodesy.osgr.Osgr: Ordnance Survey Grid References (OSGR) coordinates on the National Grid.
      - pygeodesy.utmupsBase.UtmUpsBase: (INTERNAL) Base class for Utm and Ups coordinates.
        - pygeodesy.ups.Ups: Universal Polar Stereographic (UPS) coordinate.
        - pygeodesy.utm.Utm: Universal Transverse Mercator (UTM) coordinate.
          - pygeodesy.etm.Etm: Exact Transverse Mercator (ETM) coordinate, a sub-class of Utm, a Universal Transverse Mercator (UTM) coordinate using the ExactTransverseMercator projection for highest accuracy.
      - pygeodesy.vector3dBase.Vector3dBase: (INTERNAL) Generic 3-D vector base class.
        - pygeodesy.vector3d.Vector3d: Extended 3-D vector.
          - pygeodesy.cartesianBase.CartesianBase: (INTERNAL) Base class for ellipsoidal and spherical `Cartesian`.
            - pygeodesy.ellipsoidalBase.CartesianEllipsoidalBase: (INTERNAL) Base class for ellipsoidal `Cartesian`s.
              - pygeodesy.ellipsoidalExact.Cartesian: Extended to convert exact Cartesian to exact LatLon points.
              - pygeodesy.ellipsoidalGeodSolve.Cartesian: Extended to convert exact Cartesian to exact LatLon points.
              - pygeodesy.ellipsoidalVincenty.Cartesian: Extended to convert geocentric, Cartesian points to Vincenty-based, ellipsoidal, geodetic LatLon.
              - pygeodesy.ellipsoidalNvector.Cartesian: Extended to convert geocentric, Cartesian points to `Nvector` and n-vector-based, geodetic LatLon.
              - pygeodesy.ellipsoidalKarney.Cartesian: Extended to convert `Karney`-based Cartesian to `Karney`-based LatLon points.
            - pygeodesy.sphericalBase.CartesianSphericalBase: (INTERNAL) Base class for spherical `Cartesian`s.
              - pygeodesy.sphericalNvector.Cartesian: Extended to convert geocentric, Cartesian points to `Nvector` and n-vector-based, spherical LatLon.
              - pygeodesy.sphericalTrigonometry.Cartesian: Extended to convert geocentric, Cartesian points to spherical, geodetic LatLon.
          - pygeodesy.nvectorBase.NvectorBase: (INTERNAL) Base class for ellipsoidal and spherical `Nvector`s.
            - pygeodesy.deprecated.nvector.Nvector: DEPRECATED on 2021.05.20, see (INTERNAL) class pygeodesy.nvectorBase.NvectorBase.
            - pygeodesy.ellipsoidalNvector.Nvector: An n-vector is a position representation using a (unit) vector normal to the earth ellipsoid.
            - pygeodesy.sphericalNvector.Nvector: An n-vector is a position representation using a (unit) vector normal to the earth's surface.
          - pygeodesy.ltpTuples._Vector3d
            - pygeodesy.ltpTuples.Uvw: 3-D `u-v-w` (UVW) components.
            - pygeodesy.ltpTuples.XyzLocal: Local `(x, y, z)` in a local tangent plane (LTP), also base class for local Enu.
              - pygeodesy.ltpTuples.Enu: Local `Eeast-North-Up` (ENU) location in a local tangent plane.
      - pygeodesy.webmercator.Wm: Web Mercator (WM) coordinate.
      - pygeodesy.ltpTuples._AbcBase: (INTERNAL) Base class for classes `Aer` and `Ned`.
        - pygeodesy.ltpTuples.Aer: Local `Azimuth-Elevation-Range` (AER) in a local tangent plane.
          - pygeodesy.ltpTuples.Los: A Line-Of-Sight (LOS) from a `LatLon` or `Cartesian` location.
        - pygeodesy.ltpTuples.Ned: Local `North-Eeast-Down` (NED) location in a local tangent plane.
          - pygeodesy.ellipsoidalNvector.Ned: DEPRECATED on 2024.02.04, use class pygeodesy.Ned.
      - pygeodesy.albers._AlbersBase: (INTERNAL) Base class for `AlbersEqualArea...` projections.
        - pygeodesy.albers.AlbersEqualArea: An Albers equal-area (authalic) projection with a single standard parallel.
        - pygeodesy.albers.AlbersEqualArea2: An Albers equal-area (authalic) projection with two standard parallels.
        - pygeodesy.albers.AlbersEqualArea4: An Albers equal-area (authalic) projection specified by the `sin` and `cos` of both standard parallels.
        - pygeodesy.albers.AlbersEqualAreaCylindrical: An AlbersEqualArea projection at `lat=0` and `k0=1` degenerating to the cylindrical-equal-area projection.
        - pygeodesy.albers.AlbersEqualAreaNorth: An azimuthal AlbersEqualArea projection at `lat=90` and `k0=1` degenerating to the azimuthal LambertEqualArea projection.
        - pygeodesy.albers.AlbersEqualAreaSouth: An azimuthal AlbersEqualArea projection at `lat=-90` and `k0=1` degenerating to the azimuthal LambertEqualArea projection.
      - pygeodesy.azimuthal._AzimuthalBase: (INTERNAL) Base class for azimuthal projections.
        - pygeodesy.azimuthal.Equidistant: Azimuthal equidistant projection for the sphere***, see Snyder, pp 195-197 and MathWorld-Wolfram.
        - pygeodesy.azimuthal.Gnomonic: Azimuthal gnomonic projection for the sphere***, see Snyder, pp 164-168 and MathWorld-Wolfram.
        - pygeodesy.azimuthal.LambertEqualArea: Lambert-equal-area projection for the sphere*** (aka Lambert zenithal equal-area projection, see Snyder, pp 185-187 and MathWorld-Wolfram.
        - pygeodesy.azimuthal.Orthographic: Orthographic projection for the sphere***, see Snyder, pp 148-153 and MathWorld-Wolfram.
        - pygeodesy.azimuthal.Stereographic: Stereographic projection for the sphere***, see Snyder, pp 157-160 and MathWorld-Wolfram.
        - pygeodesy.azimuthal._AzimuthalGeodesic: (INTERNAL) Base class for azimuthal projections using the wrapped geodesic.Geodesic and geodesicline.GeodesicLine or the exact geodesic classes GeodesicExact and GeodesicLineExact.
          - pygeodesy.azimuthal._EquidistantBase: (INTERNAL) Base for classes EquidistantExact, EquidistantGeodSolve and EquidistantKarney.
            - pygeodesy.azimuthal.EquidistantExact: Azimuthal equidistant projection, a Python version of Karney's C++ class AzimuthalEquidistant, based on exact geodesic classes GeodesicExact and GeodesicLineExact.
            - pygeodesy.azimuthal.EquidistantGeodSolve: Azimuthal equidistant projection, a Python version of Karney's C++ class AzimuthalEquidistant, based on (exact) geodesic wrappers GeodesicSolve and GeodesicLineSolve and intended for testing purposes only.
            - pygeodesy.azimuthal.EquidistantKarney: Azimuthal equidistant projection, a Python version of Karney's C++ class AzimuthalEquidistant, requiring package geographiclib to be installed.
          - pygeodesy.azimuthal._GnomonicBase: (INTERNAL) Base for classes GnomonicExact, GnomonicGeodSolve and GnomonicKarney.
            - pygeodesy.azimuthal.GnomonicExact: Azimuthal gnomonic projection, a Python version of Karney's C++ class Gnomonic, based on exact geodesic classes GeodesicExact and GeodesicLineExact.
            - pygeodesy.azimuthal.GnomonicGeodSolve: Azimuthal gnomonic projection, a Python version of Karney's C++ class Gnomonic, based on (exact) geodesic wrappers GeodesicSolve and GeodesicLineSolve and intended for testing purposes only.
            - pygeodesy.azimuthal.GnomonicKarney: Azimuthal gnomonic projection, a Python version of Karney's C++ class Gnomonic, requiring package geographiclib to be installed.
      - pygeodesy.karney._CapsBase: (INTERNAL) Base class for `Geodesic*`, `Geodesic*Exact`, `Intersectool` and `Rhumb*Base`.
        - pygeodesy.rhumb.bases.RhumbBase: (INTERNAL) Base class for `rhumb.aux_.RhumbAux` and `rhumb.ekx.Rhumb`.
          - pygeodesy.rhumb.ekx.Rhumb: Class to solve the direct and inverse rhumb problems, based on elliptic functions or Krüger series expansion
          - pygeodesy.rhumb.aux_.RhumbAux: Class to solve the direct and inverse rhumb problems, based on Auxiliary Latitudes for accuracy near the poles.
        - pygeodesy.rhumb.bases.RhumbLineBase: (INTERNAL) Base class for `rhumb.aux_.RhumbLineAux` and `rhumb.ekx.RhumbLine`.
          - pygeodesy.rhumb.ekx.RhumbLine: Compute one or several points on a single rhumb line.
          - pygeodesy.rhumb.aux_.RhumbLineAux: Compute one or several points on a single rhumb line.
        - pygeodesy.geodesicx.gxbases._GeodesicBase: (INTERNAL) Base class for `[_]Geodesic*Exact`.
          - pygeodesy.geodesicx.gx.GeodesicExact: A pure Python version of Karney's C++ class GeodesicExact, modeled after Karney's Python class geodesic.Geodesic.
          - pygeodesy.geodesicx.gxline._GeodesicLineExact: (INTERNAL) Base class for GeodesicLineExact.
            - pygeodesy.geodesicx.gx.GeodesicLineExact: A pure Python version of Karney's C++ class GeodesicLineExact, modeled after Karney's Python class geodesicline.GeodesicLine.
        - pygeodesy.solveBase._SolveCapsBase: (NTERNAL) Base class for `_SolveBase` and `_LineSolveBase`.
          - pygeodesy.geodesici.Intersectool: Wrapper to invoke Karney's utility IntersectTool similar to class Intersector.
          - pygeodesy.solveBase._SolveBase: (INTERNAL) Base class for `_SolveBase` and `_SolveLineBase`.
            - pygeodesy.solveBase._Solve3Base: (NTERNAL) Base class for `_Geodesic[3]SolveBase`.
              - pygeodesy.geod3solve._Geodesic3SolveBase: (INTERNAL) Base class for Geodesic3Solve and GeodesicLine3Solve.
                - pygeodesy.geod3solve.Geodesic3Solve: Wrapper to invoke Karney's Geod3Solve as a `triaxial` version of Karney's Python class Geodesic.
                - pygeodesy.geod3solve.GeodesicLine3Solve: Wrapper to invoke Karney's Geod3Solve as a `triaxial` version of Karney's Python class GeodesicLine.
              - pygeodesy.solveBase._SolveGDictBase: (NTERNAL) Base class for `_GeodesicSolveBase` and `_RhumbSolveBase`.
                - pygeodesy.geodsolve._GeodesicSolveBase: (INTERNAL) Base class for GeodesicSolve and GeodesicLineSolve.
                  - pygeodesy.geodsolve.GeodesicLineSolve: Wrapper to invoke Karney's GeodSolve as an `Exact` version of Karney's Python class GeodesicLine.
                  - pygeodesy.geodsolve.GeodesicSolve: Wrapper to invoke Karney's GeodSolve as an `Exact` version of Karney's Python class Geodesic.
                - pygeodesy.rhumb.solve._RhumbSolveBase: (INTERNAL) Base class for RhumbSolve and RhumbLineSolve.
                  - pygeodesy.rhumb.solve.RhumbLineSolve: Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.RhumbLine and pygeodesy.RhumbLineAux.
                  - pygeodesy.rhumb.solve.RhumbSolve: Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.Rhumb and pygeodesy.RhumbAux.
                - pygeodesy.solveBase._SolveGDictLineBase: (NTERNAL) Base class for `GeodesicLineSolve` and `RhumbLineSolve`.
                  - pygeodesy.geodsolve.GeodesicLineSolve: Wrapper to invoke Karney's GeodSolve as an `Exact` version of Karney's Python class GeodesicLine.
                  - pygeodesy.rhumb.solve.RhumbLineSolve: Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.RhumbLine and pygeodesy.RhumbLineAux.
        - pygeodesy.karney._kWrapped: (INTERNAL) Wrapper for some of Karney's geographiclib classes.
          - pygeodesy.geodesicw._gWrapped: (INTERNAL) Wrapper for some of Karney's geographiclib classes.
            - pygeodesy.geodesicw.Geodesic: Wrapper around Karney's class geographiclib.geodesic.Geodesic.
            - pygeodesy.geodesicw.GeodesicLine: Wrapper around Karney's class geographiclib.geodesicline.GeodesicLine.
      - pygeodesy.ecef._EcefBase: (INTERNAL) Base class for `Ecef*` conversion classes.
        - pygeodesy.ecef.EcefFarrell21: Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates based on Jay A. Farrell's Table 2.1, page 29.
        - pygeodesy.ecef.EcefFarrell22: Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates based on Jay A. Farrell's Table 2.2, page 30.
        - pygeodesy.ecef.EcefKarney: Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates transcoded from Karney's C++ Geocentric methods.
        - pygeodesy.ecef.EcefSudano: Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates based on John J. Sudano's paper.
        - pygeodesy.ecef.EcefUPC: Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates based on UPC's method.
        - pygeodesy.ecef.EcefVeness: Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates transcoded from Chris Veness' JavaScript classes LatLonEllipsoidal, Cartesian.
        - pygeodesy.ecef.EcefYou: Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates using Rey-Jer You's transformation for non-prolate ellipsoids.
      - pygeodesy.geodesici._IntersectBase: (INTERNAL) Base class for Intersectool and Intersector.
        - pygeodesy.geodesici.Intersectool: Wrapper to invoke Karney's utility IntersectTool similar to class Intersector.
        - pygeodesy.geodesici.Intersector: Finder of intersections between two goedesic lines, each an instance of GeodesicLineExact, wrapped GeodesicLine or GeodesicLineSolve.
      - pygeodesy.named._NamedEnumItem: (INTERNAL) Base class for items in a `_NamedEnum` registry.
        - pygeodesy.lcc.Conic: Lambert conformal conic projection (1- or 2-SP).
        - pygeodesy.datums.Datum: Ellipsoid and transform parameters for an earth model.
        - pygeodesy.ellipsoids.Ellipsoid: Ellipsoid with equatorial and polar radii, flattening, inverse flattening and other, often used, cached attributes, supporting oblate and prolate ellipsoidal and spherical earth models.
          - pygeodesy.ellipsoids.Ellipsoid2: An Ellipsoid specified by equatorial radius and flattening.
        - pygeodesy.trf.RefFrame: Terrestrial Reference Frame (TRF) parameters.
        - pygeodesy.datums.Transform: Helmert datum transformation.
          - pygeodesy.trf.TransformXform: Helmert transformation, extended with an `Xform` TRF converter.
        - pygeodesy.triaxials.bases._UnOrderedTriaxialBase: (INTERNAL) Base class for all unordered triaxial classes.
          - pygeodesy.triaxials.triaxial5.Triaxial_: Unordered triaxial ellipsoid.
          - pygeodesy.triaxials.bases._OrderedTriaxialBase: (INTERNAL) Base class for all ordered triaxial classes.
            - pygeodesy.triaxials.triaxial5.Triaxial: Ordered triaxial ellipsoid.
              - pygeodesy.triaxials.triaxial5.Conformal: This is a Jacobi Conformal projection of a triaxial ellipsoid to a plane where the `X` and `Y` grid lines are straight.
                - pygeodesy.triaxials.triaxial5.ConformalSphere: Alternate, Jacobi Conformal projection on a spherical triaxial.
                  - pygeodesy.deprecated.classes.JacobiConformalSpherical: DEPRECATED on 2025.10.25, use class ConformalSphere.
                - pygeodesy.deprecated.classes.JacobiConformal: DEPRECATED on 2025.10.25, use class Conformal.
            - pygeodesy.triaxials.bases._Triaxial3Base: (INTERNAL) Base class for unordered triaxial`3` classes.
              - pygeodesy.triaxials.conformal3.Conformal3: Jacobi Conformal projection of triaxial ellipsoid using class Ang lat- and longitudes.
                - pygeodesy.triaxials.conformal3.Conformal3B: Jacobi Conformal projection on a triaxial ellipsoid specified by its middle semi-axis and shape.
              - pygeodesy.triaxials.triaxial3.Triaxial3: Ordered triaxial ellipsoid convering between cartesian and lat-/longitudes using using class Ang.
                - pygeodesy.triaxials.triaxial3.Triaxial3B: Triaxial ellipsoid specified by its middle semi-axis and shape.
                  - pygeodesy.triaxials.conformal3.Conformal3Sphere: Jacobi Conformal projection on a spherical triaxial.
    - pygeodesy.named._NamedDict: (INTERNAL) Named `dict` with key and attribute access to the items.
      - pygeodesy.geohash.Neighbors8Dict: 8-Dict `(N, NE, E, SE, S, SW, W, NW)` of Geohashes, providing key and attribute access to the items.
      - pygeodesy.named._NamedEnum: (INTERNAL) Enum-like `_NamedDict` with attribute access restricted to valid keys.
    - pygeodesy.named._NamedTuple: (INTERNAL) Base for named `tuple`s with both index and attribute name access to the items.
      - pygeodesy.albers.Albers7Tuple: 7-Tuple `(x, y, lat, lon, gamma, scale, datum)`, in `meter`, `meter`, `degrees90`, `degrees180`, `degrees360`, `scalar` and `Datum` where `(x, y)` is the projected, `(lat, lon)` the geodetic location, `gamma` the meridian convergence at point, the bearing of the y-axis measured clockwise from true North and `scale` is the azimuthal scale of the projection at point.
      - pygeodesy.karney.Area3Tuple: 3-Tuple `(number, perimeter, area)` with the `number` of points of the polygon or polyline, the `perimeter` in `meter` and the `area` in `meter` squared.
      - pygeodesy.ltpTuples.Attitude4Tuple: 4-Tuple `(alt, tilt, yaw, roll)` with `altitude` in (positive) `meter` and `tilt`, `yaw` and `roll` in `degrees` representing the attitude of a plane or camera.
      - pygeodesy.azimuthal.Azimuthal7Tuple: 7-Tuple `(x, y, lat, lon, azimuth, scale, datum)`, in `meter`, `meter`, `degrees90`, `degrees180`, compass `degrees`, `scalar` and `Datum` where `(x, y)` is the easting and northing of a projected point, `(lat, lon)` the geodetic location, `azimuth` the azimuth, clockwise from true North and `scale` is the projection scale, either `1 / reciprocal` or `1` or `-1` in the Equidistant case.
      - pygeodesy.namedTuples.Bearing2Tuple: 2-Tuple `(initial, final)` bearings, both in compass `degrees360`.
      - pygeodesy.namedTuples.Bounds2Tuple: 2-Tuple `(latlonSW, latlonNE)` with the bounds' lower-left and upper-right corner as `LatLon` instance.
      - pygeodesy.namedTuples.Bounds4Tuple: 4-Tuple `(latS, lonW, latN, lonE)` with the bounds' lower-left `(LatS, LowW)` and upper-right `(latN, lonE)` corner lat- and longitudes.
      - pygeodesy.ltpTuples.ChLVEN2Tuple: 2-Tuple `(E_LV95, N_LV95)` with falsed Swiss LV95 easting and norting in `meter (2_600_000, 1_200_000)` and origin at `Bern, Ch`.
      - pygeodesy.ltpTuples.ChLVYX2Tuple: 2-Tuple `(Y, X)` with unfalsed Swiss LV95 easting and norting in `meter`.
      - pygeodesy.ltpTuples.ChLVyx2Tuple: 2-Tuple `(y_LV03, x_LV03)` with falsed Swiss LV03 easting and norting in `meter (600_000, 200_000)` and origin at `Bern, Ch`.
      - pygeodesy.vector2d.Circin6Tuple: 6-Tuple `(radius, center, deltas, cA, cB, cC)` with the `radius`, the trilaterated `center` and contact points of the inscribed aka In- circle of a triangle.
      - pygeodesy.namedTuples.Circle4Tuple: 4-Tuple `(radius, height, lat, beta)` with the `radius` and `height` of a parallel circle of latitude at (geodetic) latitude `lat` and parametric (or reduced) auxiliary latitude `beta` on a biaxial ellipsoid.
      - pygeodesy.vector2d.Circum3Tuple: 3-Tuple `(radius, center, deltas)` with the `circumradius` and trilaterated `circumcenter` of the `circumcircle` through 3 points (aka {Meeus}' Type II circle) or the `radius` and `center` of the smallest Meeus' Type I circle.
      - pygeodesy.vector2d.Circum4Tuple: 4-Tuple `(radius, center, rank, residuals)` with `radius` and `center` of a sphere least-squares fitted through given points and the `rank` and `residuals` -if any- from numpy.linalg.lstsq.
      - pygeodesy.clipy.ClipCS4Tuple: 4-Tuple `(start, end, i, j)` for each edge of a clipped path with the `start` and `end` points (`LatLon`) of the portion of the edge inside or on the clip box and the indices `i` and `j` (`int`) of the edge start and end points in the original path.
      - pygeodesy.clipy.ClipFHP4Tuple: 4-Tuple `(lat, lon, height, clipid)` for each point of the clipFHP4 result with the `lat`-, `lon`gitude, `height` and `clipid` of the polygon or clip.
        - pygeodesy.clipy.ClipGH4Tuple: 4-Tuple `(lat, lon, height, clipid)` for each point of the clipGH4 result with the `lat`-, `lon`gitude, `height` and `clipid` of the polygon or clip.
      - pygeodesy.clipy.ClipLB6Tuple: 6-Tuple `(start, end, i, fi, fj, j)` for each edge of the clipped path with the `start` and `end` points (`LatLon`) of the portion of the edge inside or on the clip box, indices `i` and `j` (both `int`) of the original path edge start and end points and fractional indices `fi` and `fj` (both FIx) of the `start` and `end` points along the edge of the original path.
      - pygeodesy.clipy.ClipSH3Tuple: 3-Tuple `(start, end, original)` for each edge of a clipped polygon, the `start` and `end` points (`LatLon`) of the portion of the edge inside or on the clip region and `original` indicates whether the edge is part of the original polygon or part of the clip region (`bool`).
      - pygeodesy.resections.Collins5Tuple: 5-Tuple `(pointP, pointH, a, b, c)` with survey `pointP`, auxiliary `pointH`, each an instance of `pointA`'s (sub-)class and triangle sides `a`, `b` and `c` in `meter`, conventionally.
      - pygeodesy.triaxials.bases.Conformal5Tuple: 5-Tuple `(x, y, z, scale, llk)` with the easting `x` and northing `y` projection, `scale` or `NAN` but with `z=INT0` and kind `llk=LLK.CONFORMAL` always.
      - pygeodesy.ellipsoids.Curvature2Tuple: 2-Tuple `(meridional, prime_vertical)` of radii of curvature, both in `meter`, conventionally.
      - pygeodesy.namedTuples.Destination2Tuple: 2-Tuple `(destination, final)`, `destination` in `LatLon` and `final` bearing in compass `degrees360`.
      - pygeodesy.namedTuples.Destination3Tuple: 3-Tuple `(lat, lon, final)`, destination `lat`, `lon` in `degrees90` respectively `degrees180` and `final` bearing in compass `degrees360`.
      - pygeodesy.namedTuples.Distance2Tuple: 2-Tuple `(distance, initial)`, `distance` in `meter` and `initial` bearing in compass `degrees360`.
      - pygeodesy.namedTuples.Distance3Tuple: 3-Tuple `(distance, initial, final)`, `distance` in `meter` and `initial` and `final` bearing, both in compass `degrees360`.
      - pygeodesy.namedTuples.Distance4Tuple: 4-Tuple `(distance2, delta_lat, delta_lon, unroll_lon2)` with the distance in `degrees squared`, the latitudinal `delta_lat = lat2 - lat1`, the wrapped, unrolled and adjusted longitudinal `delta_lon = lon2 - lon1` and `unroll_lon2`, the unrolled or original `lon2`.
      - pygeodesy.fsums.DivMod2Tuple: 2-Tuple `(div, mod)` with the quotient `div` and remainder `mod` results of a `divmod` operation.
      - pygeodesy.namedTuples.EasNor2Tuple: 2-Tuple `(easting, northing)`, both in `meter`, conventionally.
      - pygeodesy.namedTuples.EasNor3Tuple: 3-Tuple `(easting, northing, height)`, all in `meter`, conventionally.
      - pygeodesy.css.EasNorAziRk4Tuple: 4-Tuple `(easting, northing, azimuth, reciprocal)` for the Cassini-Soldner location with `easting` and `northing` in `meters` and the `azimuth` of easting direction and `reciprocal` of azimuthal northing scale, both in `degrees`.
      - pygeodesy.css.EasNorAziRkEqu6Tuple: 6-Tuple `(easting, northing, azimuth, reciprocal, equatorarc, equatorazimuth)` for the Cassini-Soldner location with `easting` and `northing` in `meters` and the `azimuth` of easting direction, `reciprocal` of azimuthal northing scale, `equatorarc` and `equatorazimuth`, all in `degrees`.
      - pygeodesy.webmercator.EasNorRadius3Tuple: 3-Tuple `(easting, northing, radius)`, all in `meter`.
      - pygeodesy.ecef.Ecef9Tuple: 9-Tuple `(x, y, z, lat, lon, height, C, M, datum)` with geocentric `x`, `y` and `z` plus geodetic `lat`, `lon` and `height`, case `C` and optionally, rotation matrix `M` (EcefMatrix) and `datum`, with `lat` and `lon` in `degrees` and `x`, `y`, `z` and `height` in `meter`, conventionally.
      - pygeodesy.ecef.EcefMatrix: A rotation matrix known as East-North-Up (ENU) to ECEF.
      - pygeodesy.elevations.Elevation2Tuple: 2-Tuple `(elevation, data_source)` in `meter` and `str`.
      - pygeodesy.namedTuples.Ellipse5Tuple: 5-Tuple `(a, b, height, lat, beta)` with semi-axes `a` and `b` of a parallel ellipse of latitude at (geodetic) latitude `lat` and parametric (or reduced) auxiliary latitude `beta` of a triaxial ellipsoid.
      - pygeodesy.elliptic.Elliptic3Tuple: 3-Tuple `(sn, cn, dn)` all `scalar`.
      - pygeodesy.ltpTuples.Footprint5Tuple: 5-Tuple `(center, upperleft, upperight, loweright, lowerleft)` with the `center` and 4 corners of the local projection of a `Frustum`, each an Xyz4Tuple, XyzLocal, `LatLon`, etc.
      - pygeodesy.namedTuples.Forward4Tuple: 4-Tuple `(easting, northing, gamma, scale)` in `meter`, `meter`, meridian convergence `gamma` at point in `degrees` and the `scale` of projection at point `scalar`.
      - pygeodesy.frechet.Frechet6Tuple: 6-Tuple `(fd, fi1, fi2, r, n, units)` with the discrete Fréchet distance `fd`, fractional indices `fi1` and `fi2` as `FIx`, the recursion depth `r`, the number of distances computed `n` and the units class or name of the distance `units`.
      - pygeodesy.fsums.Fsum2Tuple: 2-Tuple `(fsum, residual)` with the precision running `fsum` and the `residual`, the sum of the remaining partials.
      - pygeodesy.elevations.GeoidHeight2Tuple: 2-Tuple `(height, model_name)`, geoid `height` in `meter` and `model_name` as `str`.
      - pygeodesy.geoids.GeoidHeight5Tuple: 5-Tuple `(lat, lon, egm84, egm96, egm2008)` for GeoidHeights.dat tests with the heights for 3 different EGM grids at `degrees90` and `degrees180` degrees (after converting `lon` from original `0 <= EasterLon <= 360`).
      - pygeodesy.hausdorff.Hausdorff6Tuple: 6-Tuple `(hd, i, j, mn, md, units)` with the Hausdorff distance `hd`, indices `i` and `j`, the total count `mn`, the `mean Hausdorff` distance `md` and the class or name of both distance `units`.
      - pygeodesy.geodesici.Intersect7Tuple: 7-Tuple `(A, B, sAB, aAB, c, kA, kB)` with `A` and `B` each a `LatLon` or LatLon4Tuple`(lat, lon, height, datum)` of the intersection on each geodesic line, the distance `sAB` in in `meter` and angular distance `aAB` in `degrees` between `A` and `B`, coincidence indicator `c` and segment indicators `kA` and `kB` all `int`, see XDict and method intersect7.
      - pygeodesy.namedTuples.Intersection3Tuple: 3-Tuple `(point, outside1, outside2)` of an intersection `point` and `outside1`, the position of the `point`, `-1` if before the start, `+1` if after the end and `0` if on or between the start and end point of the first line.
      - pygeodesy.geodesici.Intersectool5Tuple: 5-Tuple `(A, B, sAB, aAB, c)` with `A` and `B` the `Position` of the intersection on each geodesic line, the distance `sAB` between `A` and `B` in `meter`, the angular distance `aAB` in `degrees` and coincidence indicator `c` (`int`), see XDict.
        - pygeodesy.geodesici.Intersector5Tuple: 5-Tuple `(A, B, sAB, aAB, c)` with `A` and `B` the `Position` of the intersection on each geodesic line, the distance `sAB` between `A` and `B` in `meter`, angular distance `aAB` in `degrees` and coincidence indicator `c` (`int`), see XDict.
        - pygeodesy.geodesici.Middle5Tuple: 5-Tuple `(A, B, sMM, aMM, c)` with `A` and `B` the line segments including the mid-point location in `latM`, `lonM`, distance `s1M` in `meter` and angular distance `a1M` in `degrees`, the distance between both mid-points `sMM` in `meter` and angular distance `aMM` in `degrees` and coincidence indicator `c` (`int`).
      - pygeodesy.namedTuples.LatLon2Tuple: 2-Tuple `(lat, lon)` in `degrees90` and `degrees180`.
      - pygeodesy.namedTuples.LatLon3Tuple: 3-Tuple `(lat, lon, height)` in `degrees90`, `degrees180` and `meter`, conventionally.
        - pygeodesy.namedTuples.LatLon4Tuple: 4-Tuple `(lat, lon, height, datum)` in `degrees90`, `degrees180`, `meter` and Datum.
      - pygeodesy.css.LatLonAziRk4Tuple: 4-Tuple `(lat, lon, azimuth, reciprocal)`, all in `degrees` where `azimuth` is the azimuth of easting direction and `reciprocal` the reciprocal of azimuthal northing scale.
      - pygeodesy.namedTuples.LatLonDatum3Tuple: 3-Tuple `(lat, lon, datum)` in `degrees90`, `degrees180` and Datum.
        - pygeodesy.namedTuples.LatLonDatum5Tuple: 5-Tuple `(lat, lon, datum, gamma, scale)` in `degrees90`, `degrees180`, Datum, `degrees` and `float`.
      - pygeodesy.namedTuples.LatLonPrec3Tuple: 3-Tuple `(lat, lon, precision)` in `degrees`, `degrees` and `int`.
        - pygeodesy.namedTuples.LatLonPrec5Tuple: 5-Tuple `(lat, lon, precision, height, radius)` in `degrees`, `degrees`, `int` and `height` or `radius` in `meter` (or `None` if missing).
      - pygeodesy.ltpTuples.Local9Tuple: 9-Tuple `(x, y, z, lat, lon, height, ltp, ecef, M)` with local `x`, `y`, `z` all in `meter`, geodetic `lat`, `lon`, `height`, local tangent plane `ltp` (Ltp), `ecef` (Ecef9Tuple) with geocentric `x`, `y`, `z`, geodetic `lat`, `lon`, `height` and concatenated rotation matrix `M` (EcefMatrix) or `None`.
        - pygeodesy.ltpTuples.ChLV9Tuple: 9-Tuple `(Y, X, h_, lat, lon, height, ltp, ecef, M)` with unfalsed Swiss (Y, X, h_) coordinates and height, all in `meter`, `ltp` either a ChLV, ChLVa or ChLVe instance and `ecef` (EcefKarney at Bern, Ch), otherwise like Local9Tuple.
      - pygeodesy.vector2d.Meeus2Tuple: 2-Tuple `(radius, Type)` with `radius` and Meeus' `Type` of the smallest circle containing 3 points.
      - pygeodesy.mgrs.Mgrs4Tuple: 4-Tuple `(zone, EN, easting, northing)`, `zone` and grid tile `EN` as `str`, `easting` and `northing` in `meter`.
      - pygeodesy.mgrs.Mgrs6Tuple: 6-Tuple `(zone, EN, easting, northing, band, datum)`, with `zone`, grid tile `EN` and `band` as `str`, `easting` and `northing` in `meter` and `datum` a Datum.
      - pygeodesy.namedTuples.NearestOn2Tuple: 2-Tuple `(closest, fraction)` of the `closest` point on and `fraction` along a line (segment) between two points.
      - pygeodesy.namedTuples.NearestOn3Tuple: 3-Tuple `(closest, distance, angle)` of the `closest` point on the polygon, either a `LatLon` instance or a LatLon3Tuple`(lat, lon, height)` and the `distance` and `angle` to the `closest` point are in `meter` respectively compass `degrees360`.
      - pygeodesy.namedTuples.NearestOn6Tuple: 6-Tuple `(closest, distance, fi, j, start, end)` with the `closest` point, the `distance` in `meter`, conventionally and the `start` and `end` point of the path or polygon edge.
      - pygeodesy.namedTuples.NearestOn8Tuple: 8-Tuple `(closest, distance, fi, j, start, end, initial, final)`, like NearestOn6Tuple but extended with the `initial` and the `final` bearing at the reference respectively the `closest` point, both in compass `degrees`.
      - pygeodesy.namedTuples.PhiLam2Tuple: 2-Tuple `(phi, lam)` with latitude `phi` in `radians[PI_2]` and longitude `lam` in `radians[PI]`.
      - pygeodesy.namedTuples.PhiLam3Tuple: 3-Tuple `(phi, lam, height)` with latitude `phi` in `radians[PI_2]`, longitude `lam` in `radians[PI]` and `height` in `meter`.
      - pygeodesy.namedTuples.PhiLam4Tuple: 4-Tuple `(phi, lam, height, datum)` with latitude `phi` in `radians[PI_2]`, longitude `lam` in `radians[PI]`, `height` in `meter` and Datum.
      - pygeodesy.namedTuples.Point3Tuple: 3-Tuple `(x, y, ll)` in `meter`, `meter` and `LatLon`.
      - pygeodesy.namedTuples.Points2Tuple: 2-Tuple `(number, points)` with the `number` of points and -possible reduced- `list` or `tuple` of `points`.
      - pygeodesy.formy.Radical2Tuple: 2-Tuple `(ratio, xline)` of the radical `ratio` and radical `xline`, both `scalar` and `0.0 <= ratio <= 1.0`
      - pygeodesy.vector2d.Radii11Tuple: 11-Tuple `(rA, rB, rC, cR, rIn, riS, roS, a, b, c, s)` with the `Tangent` circle radii `rA`, `rB` and `rC`, the `circumradius` `cR`, the `Incircle` radius `rIn` aka `inradius`, the inner and outer Soddy circle radii `riS` and `roS`, the sides `a`, `b` and `c` and semi-perimeter `s` of a triangle, all in `meter` conventionally.
      - pygeodesy.geohash.Resolutions2Tuple: 2-Tuple `(res1, res2)` with the primary (longitudinal) and secondary (latitudinal) resolution, both in `degrees`.
      - pygeodesy.namedTuples.Reverse4Tuple: 4-Tuple `(lat, lon, gamma, scale)` with `lat`- and `lon`gitude in `degrees`, meridian convergence `gamma` at point in `degrees` and the `scale` of projection at point `scalar`.
      - pygeodesy.points.Shape2Tuple: 2-Tuple `(nrows, ncols)`, the number of rows and columns, both `int`.
      - pygeodesy.geohash.Sizes3Tuple: 3-Tuple `(height, width, radius)` with latitudinal `height`, longitudinal `width` and area `radius`, all in `meter`.
      - pygeodesy.vector2d.Soddy4Tuple: 4-Tuple `(radius, center, deltas, outer)` with `radius` and (trilaterated) `center` of the inner Soddy circle and the radius of the `outer` Soddy circle.
      - pygeodesy.resections.Survey3Tuple: 3-Tuple `(PA, PB, PC)` with distance from survey point `P` to each of the triangle corners `A`, `B` and `C` in `meter`, conventionally.
      - pygeodesy.trf.TRFXform7Tuple: 7-Tuple `(tx, ty, tz, s, sx, sy, sz)` of conversion parameters with translations `tx`, `ty` and `tz` in `milli-meter`, scale `s` in `ppB` and rotations `sx`, `sy` and `sz` in `milli-arc-seconds`.
      - pygeodesy.resections.Tienstra7Tuple: 7-Tuple `(pointP, A, B, C, a, b, c)` with survey `pointP`, interior triangle angles `A`, `B` and `C` in `degrees` and triangle sides `a`, `b` and `c` in `meter`, conventionally.
      - pygeodesy.resections.TriAngle5Tuple: 5-Tuple `(radA, radB, radC, rIn, area)` with the interior angles at triangle corners `A`, `B` and `C` in `radians`, the `InCircle` radius `rIn` aka `inradius` in `meter` and the triangle `area` in `meter` squared, conventionally.
      - pygeodesy.resections.TriSide2Tuple: 2-Tuple `(a, radA)` with triangle side `a` in `meter`, conventionally and angle `radA` at the opposite triangle corner in `radians`.
      - pygeodesy.resections.TriSide4Tuple: 4-Tuple `(a, b, radC, d)` with interior angle `radC` at triangle corner `C` in `radians`with the length of triangle sides `a` and `b` and with triangle height `d` perpendicular to triangle side `c`, in the same units as triangle sides `a` and `b`.
      - pygeodesy.namedTuples.Triangle7Tuple: 7-Tuple `(A, a, B, b, C, c, area)` with interior angles `A`, `B` and `C` in `degrees`, spherical sides `a`, `b` and `c` in `meter` conventionally and the `area` of a (spherical) triangle in square `meter` conventionally.
      - pygeodesy.namedTuples.Triangle8Tuple: 8-Tuple `(A, a, B, b, C, c, D, E)` with interior angles `A`, `B` and `C`, spherical sides `a`, `b` and `c`, the spherical deficit `D` and the spherical excess `E` of a (spherical) triangle, all in `radians`.
      - pygeodesy.vector2d.Triaxum5Tuple: 5-Tuple `(a, b, c, rank, residuals)` with the (unordered) triaxial radii `a`, `b` and `c` of an ellipsoid least-squares fitted through given points and the `rank` and `residuals` -if any- from numpy.linalg.lstsq.
      - pygeodesy.namedTuples.Trilaterate5Tuple: 5-Tuple `(min, minPoint, max, maxPoint, n)` with `min` and `max` in `meter`, the corresponding trilaterated `minPoint` and `maxPoint` as `LatLon` and the number `n`.
      - pygeodesy.namedTuples.UtmUps2Tuple: 2-Tuple `(zone, hemipole)` as `int` and `str`, where `zone` is `1..60` for UTM or `0` for UPS and `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole.
      - pygeodesy.namedTuples.UtmUps5Tuple: 5-Tuple `(zone, hemipole, easting, northing, band)` as `int`, `str`, `meter`, `meter` and `band` letter, where `zone` is `1..60` for UTM or `0` for UPS, `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole and `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'`.
      - pygeodesy.namedTuples.UtmUps8Tuple: 8-Tuple `(zone, hemipole, easting, northing, band, datum, gamma, scale)` as `int`, `str`, `meter`, `meter`, `band` letter, `Datum`, `degrees` and `scalar`, where `zone` is `1..60` for UTM or `0` for UPS, `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole and `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'`.
      - pygeodesy.namedTuples.UtmUpsLatLon5Tuple: 5-Tuple `(zone, band, hemipole, lat, lon)` as `int`, `str`, `str`, `degrees90` and `degrees180`, where `zone` is `1..60` for UTM or `0` for UPS, `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'` and `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole.
      - pygeodesy.ltpTuples.Uvw3Tuple: 3-Tuple `(u, v, w)`, in `meter`.
      - pygeodesy.namedTuples.Vector2Tuple: 2-Tuple `(x, y)` of (geocentric) components, each in `meter` or the same `units`.
      - pygeodesy.namedTuples.Vector3Tuple: 3-Tuple `(x, y, z)` of (geocentric) components, all in `meter` or the same `units`.
      - pygeodesy.namedTuples.Vector4Tuple: 4-Tuple `(x, y, z, h)` of (geocentric) components, all in `meter` or the same `units`.
        - pygeodesy.triaxials.triaxial3.Cartesian5Tuple: 5-Tuple `(x, y, z, h, llk)` with cartesian `x`, `y` and `z` coordinates on and height `h` above or below the triaxial's surface and kind `llk` set to the original `LLK` or `None`.
      - pygeodesy.ltpTuples._Abc4Tuple: (INTERNAL) Base class for `Aer4Tuple`, `Enu4Tuple`, `Ned4Tuple` and `Xyz4Tuple`.
        - pygeodesy.ltpTuples.Aer4Tuple: 4-Tuple `(azimuth, elevation, slantrange, ltp)`, all in `meter` except `ltp`.
        - pygeodesy.ltpTuples.Enu4Tuple: 4-Tuple `(east, north, up, ltp)`, in `meter` except `ltp`.
        - pygeodesy.ltpTuples.Ned4Tuple: 4-Tuple `(north, east, down, ltp)`, all in `meter` except `ltp`.
        - pygeodesy.ltpTuples.Xyz4Tuple: 4-Tuple `(x, y, z, ltp)`, all in `meter` except `ltp`.
      - pygeodesy.angles._Ang3Tuple: (INTERNAL) Methods `.toDegrees`, `.toLambertian`, `.toRadians` and `.toUnit`.
        - pygeodesy.triaxials.triaxial3.BetOmgAlp5Tuple: 5-Tuple `(bet, omg, alp, h, llk)` with ellipsoidal lat- `bet`, longitude `omg` and azimuth `alp`, all in Angles on and height `h` off the triaxial's surface and kind `llk` set to `LLK.ELLIPSOIDAL`.
        - pygeodesy.triaxials.conformal3.BetOmgGam5Tuple: 5-Tuple `(bet, omg, gam, scale, llk)` with ellipsoidal lat- `bet`, longitude `omg` and meridian convergence `gam` all Angles, `scale` and kind `llk` set to `LLK.CONFORMAL`.
        - pygeodesy.triaxials.triaxial3.PhiLamZet5Tuple: 5-Tuple `(phi, lam, zet, h, llk)` with trixial lat- lat- `phi`, longitude `lam` and azimuth `zet`, all in Angles on and height `h` off the triaxial's surface and kind `llk` set to an `LLK`.
      - pygeodesy.deprecated.classes._Deprecated_NamedTuple: DEPRECATED, `_NamedTuple` base.
        - pygeodesy.deprecated.classes.ClipCS3Tuple: DEPRECATED, see DEPRECATED function pygeodesy.deprecated.clipCS3.
        - pygeodesy.deprecated.classes.EasNorExact4Tuple: DEPRECATED, use class Forward4Tuple, item `gamma` for `convergence`.
        - pygeodesy.deprecated.classes.LatLonExact4Tuple: DEPRECATED, use class Reverse4Tuple, item `gamma` for `convergence`.
        - pygeodesy.deprecated.classes.NearestOn4Tuple: DEPRECATED on 2023.10.10, see methods RhumbLine.nearestOn4 and RhumbLineAux.nearestOn4.
        - pygeodesy.deprecated.classes.Ned3Tuple: DEPRECATED, use class Ned4Tuple, ignoring item `ltp`.
        - pygeodesy.deprecated.classes.Rhumb7Tuple: DEPRECATED, use class Rhumb8Tuple, ignoring item `a12`.
        - pygeodesy.deprecated.classes.RhumbOrder2Tuple: DEPRECATED, see deprecated method Rhumb.orders.
        - pygeodesy.deprecated.classes.Transform7Tuple: DEPRECATED on 2024.02.02, use class TRFXform7Tuple, without keyword arguments.
        - pygeodesy.deprecated.classes.TriAngle4Tuple: DEPRECATED on 2023.09.14, use class TriAngle5Tuple, ignoring item `area`.
        - pygeodesy.deprecated.classes.UtmUps4Tuple: DEPRECATED and OBSOLETE, expect a UtmUps5Tuple from method `pygeodesy.Mgrs.toUtm(utm=None)`.
      - pygeodesy.karney._GTuple: (INTERNAL) Helper.
        - pygeodesy.karney.Direct9Tuple: 9-Tuple `(a12, lat2, lon2, azi2, s12, m12, M12, M21, S12)` with arc length `a12`, angles `lat2`, `lon2` and azimuth `azi2` in `degrees`, distance `s12` and reduced length `m12` in `meter` and area `S12` in `meter` squared.
        - pygeodesy.geod3solve.Geod3Solve8Tuple: 8-Tuple `(bet1, omg1, alp1, bet2, omg2, alp2, s12, a12)` with `ellipsoidal` latitudes `bet1` and `bet2`, `ellipsoidal` longitudes `omg1` and `omg2`, forward azimuths `alp1` and `alp2` in bearings from North, distance `s12` in `meter`, conventionally and approximate arc length `a12` in degrees, see Geod3Solve.
        - pygeodesy.geodsolve.GeodSolve12Tuple: 12-Tuple `(lat1, lon1, azi1, lat2, lon2, azi2, s12, a12, m12, M12, M21, S12)` with angles `lat1`, `lon1`, `azi1`, `lat2`, `lon2` and `azi2` and arc `a12` all in `degrees`, initial `azi1` and final `azi2` forward azimuths in bearings, degrees from North, distance `s12` and reduced length `m12` in `meter`, area `S12` in `meter` squared and geodesic scale factors `M12` and `M21`, both `scalar`, see GeodSolve.
        - pygeodesy.karney.Inverse10Tuple: 10-Tuple `(a12, s12, salp1, calp1, salp2, calp2, m12, M12, M21, S12)` with arc length `a12` in `degrees`, distance `s12` and reduced length `m12` in `meter`, area `S12` in `meter` squared and the sines `salp1`, `salp2` and cosines `calp1`, `calp2` of the initial `1` and final `2` (forward) azimuths.
        - pygeodesy.karney.Rhumb8Tuple: 8-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12, a12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12`, the area `S12` under the rhumb line and the angular distance `a12` between both points.
          - pygeodesy.rhumb.solve.RhumbSolve7Tuple: 7-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12` and the area `S12` under the rhumb line between both points.
        - pygeodesy.deprecated.classes.RhumbOrder2Tuple: DEPRECATED, see deprecated method Rhumb.orders.
      - pygeodesy.namedTuples._NamedTupleTo: (INTERNAL) Base for `-.toDegrees`, `-.toRadians`.
        - pygeodesy.cartesianBase.RadiusThetaPhi3Tuple: 3-Tuple `(r, theta, phi)` with radial distance `r` in `meter`, inclination `theta` (with respect to the positive z-axis) and azimuthal angle `phi` in Degrees or Radians representing a spherical, polar position.
        - pygeodesy.triaxials.triaxial5._NamedTupleToX: (INTERNAL) Base class for BetaOmega2Tuple, BetaOmega3Tuple and Conformal2Tuple.
          - pygeodesy.triaxials.triaxial5.BetaOmega2Tuple: 2-Tuple `(beta, omega)` with ellipsoidal lat- and longitude `beta` and `omega` both in Radians (or Degrees).
          - pygeodesy.triaxials.triaxial5.BetaOmega3Tuple: 3-Tuple `(beta, omega, height)` with ellipsoidal lat- and longitude `beta` and `omega` both in Radians (or Degrees) and the `height`, rather the (signed) distance to the triaxial's surface (measured along the radial line to the triaxial's center) in `meter`, conventionally.
          - pygeodesy.triaxials.triaxial5.Conformal2Tuple: 2-Tuple `(x, y)` with a Jacobi Conformal `x` and `y` projection, both in Radians (or Degrees).
            - pygeodesy.deprecated.classes.Jacobi2Tuple: DEPRECATED on 25.11.11, use class Conformal2Tuple.
      - pygeodesy.ellipsoids.a_f2Tuple: 2-Tuple `(a, f)` specifying an ellipsoid by equatorial radius `a` in `meter` and scalar flattening `f`.
    - pygeodesy.unitsBase._NamedUnit: (INTERNAL) Base class for `units`.
      - pygeodesy.units.Bool: Named `bool`, a sub-class of `int` like Python's `bool`.
      - pygeodesy.unitsBase.Float: Named `float`.
        - pygeodesy.units.Degrees: Named `float` representing a coordinate in `degrees`, optionally clipped.
          - pygeodesy.units.Azimuth: Named `float` representing an azimuth in compass `degrees` from (true) North.
          - pygeodesy.units.Bearing: Named `float` representing a bearing in compass `degrees` from (true) North.
          - pygeodesy.units.Degrees_: Named `Degrees` representing a coordinate in `degrees` with optional limits `low` and `high`.
            - pygeodesy.units.Lat_: Named `float` representing a latitude in `degrees` within limits `low` and `high`.
            - pygeodesy.units.Lon_: Named `float` representing a longitude in `degrees` within limits `low` and `high`.
          - pygeodesy.units.Lat: Named `float` representing a latitude in `degrees`.
          - pygeodesy.units.Lon: Named `float` representing a longitude in `degrees`.
        - pygeodesy.units.Degrees2: Named `float` representing a distance in `degrees squared`.
        - pygeodesy.units.Distance: Named `float` representing a distance, conventionally in `meter`.
        - pygeodesy.units.Feet: Named `float` representing a distance or length in `feet`.
        - pygeodesy.units.Float_: Named `float` with optional `low` and `high` limit.
          - pygeodesy.units.Distance_: Named `float` with optional `low` and `high` limits representing a distance, conventionally in `meter`.
          - pygeodesy.units.Epoch: Named `epoch` with optional `low` and `high` limits representing a fractional calendar year.
          - pygeodesy.units.FIx: A named Fractional Index, an `int` or `float` index into a `list` or `tuple` of `points`, typically.
          - pygeodesy.units.Height_: Named `float` with optional `low` and `high` limits representing a height, conventionally in `meter`.
          - pygeodesy.units.Meter2: Named `float` representing an area in `meter squared`.
          - pygeodesy.units.Meter3: Named `float` representing a volume in `meter cubed`.
          - pygeodesy.units.Meter_: Named `float` representing a distance or length in `meter`.
          - pygeodesy.units.Radians2: Named `float` representing a distance in `radians squared`.
          - pygeodesy.units.Radius_: Named `float` with optional `low` and `high` limits representing a radius, conventionally in `meter`.
          - pygeodesy.units.Scalar_: Named `float` with optional `low` and `high` limits representing a factor, fraction, scale, etc.
        - pygeodesy.units.Height: Named `float` representing a height, conventionally in `meter`.
          - pygeodesy.units.HeightX: Like Height, used to distinguish the interpolated height from an original Height at a clip intersection.
        - pygeodesy.units.Meter: Named `float` representing a distance or length in `meter`.
        - pygeodesy.units.Radians: Named `float` representing a coordinate in `radians`, optionally clipped.
          - pygeodesy.units.Bearing_: Named `float` representing a bearing in `radians` from compass `degrees` from (true) North.
          - pygeodesy.units.Lam: Named `float` representing a longitude in `radians`.
            - pygeodesy.units.Lamd: Named `float` representing a longitude in `radians` converted from `degrees`.
              - pygeodesy.deprecated.classes.Lam_: DEPRECATED on 2024.06.15, use class Lamd.
          - pygeodesy.angles.Lambertian: A `Lambertian` in `radians`.
          - pygeodesy.units.Phi: Named `float` representing a latitude in `radians`.
            - pygeodesy.units.Phid: Named `float` representing a latitude in `radians` converted from `degrees`.
              - pygeodesy.deprecated.classes.Phi_: DEPRECATED on 2024.06.15, use class Phid.
          - pygeodesy.units.Radians_: Named `float` representing a coordinate in `radians` with optional limits `low` and `high`.
        - pygeodesy.unitsBase.Radius: Named `float` representing a radius, conventionally in `meter`.
        - pygeodesy.units.Scalar: Named `float` representing a factor, fraction, scale, etc.
        - pygeodesy.units._EasNorBase: (INTERNAL) Easting and Northing base class.
          - pygeodesy.units.Easting: Named `float` representing an easting, conventionally in `meter`.
          - pygeodesy.units.Northing: Named `float` representing a northing, conventionally in `meter`.
      - pygeodesy.unitsBase.Int: Named `int`.
        - pygeodesy.units.Bool: Named `bool`, a sub-class of `int` like Python's `bool`.
        - pygeodesy.epsg.Epsg: EPSG class, a named `int`.
        - pygeodesy.units.Int_: Named `int` with optional limits `low` and `high`.
          - pygeodesy.units.Number_: Named `int` representing a non-negative number.
          - pygeodesy.units.Precision_: Named `int` with optional `low` and `high` limits representing a precision.
        - pygeodesy.units.Zone: Named `int` representing a UTM/UPS zone number.
      - pygeodesy.unitsBase.Str: Named, callable `str`.
        - pygeodesy.units.Band: Named `str` representing a UTM/UPS band letter, unchecked.
        - pygeodesy.gars.Garef: Garef class, a named `str`.
        - pygeodesy.geohash.Geohash: Geohash class, a named `str`.
        - pygeodesy.wgrs.Georef: Georef class, a named `str`.
  - basestring: Type basestring cannot be instantiated; it is the base for str and unicode.
    - str: str(object='') -> string
      - pygeodesy.unitsBase.Str: Named, callable `str`.
        - pygeodesy.units.Band: Named `str` representing a UTM/UPS band letter, unchecked.
        - pygeodesy.gars.Garef: Garef class, a named `str`.
        - pygeodesy.geohash.Geohash: Geohash class, a named `str`.
        - pygeodesy.wgrs.Georef: Georef class, a named `str`.
      - pygeodesy.interns.Str_: Extended, callable `str` class, not nameable.
  - dict: dict() -> new empty dictionary dict(mapping) -> new dictionary initialized from a mapping object's (key, value) pairs dict(iterable) -> new dictionary initialized as if via: d = {} for k, v in iterable: d[k] = v dict(**kwargs) -> new dictionary initialized with the name=value pairs in the keyword argument list.
    - pygeodesy.named.ADict: A `dict` with both key and attribute access to the `dict` items.
      - pygeodesy.karney.GDict: A `dict` with both `key` and `attribute` access to the `dict` items.
      - pygeodesy.geodesici.XDict: 4+Item result from Intersectool and Intersector methods `All`, `Closest`, `Next` and `Segment` with the intersection offsets `sA`, `sB` and `sX0` in `meter` and the coincidence indicator `c`, an `int`, +1 for parallel, -1 for anti-parallel or 0 otherwise.
      - pygeodesy.deprecated.classes.XDist: DEPRECATED on 2024.07.02, use class ADict.
      - pygeodesy.named._NamedDict: (INTERNAL) Named `dict` with key and attribute access to the items.
        - pygeodesy.geohash.Neighbors8Dict: 8-Dict `(N, NE, E, SE, S, SW, W, NW)` of Geohashes, providing key and attribute access to the items.
        - pygeodesy.named._NamedEnum: (INTERNAL) Enum-like `_NamedDict` with attribute access restricted to valid keys.
  - float: float(x) -> floating point number
    - pygeodesy.unitsBase.Float: Named `float`.
      - pygeodesy.units.Degrees: Named `float` representing a coordinate in `degrees`, optionally clipped.
        - pygeodesy.units.Azimuth: Named `float` representing an azimuth in compass `degrees` from (true) North.
        - pygeodesy.units.Bearing: Named `float` representing a bearing in compass `degrees` from (true) North.
        - pygeodesy.units.Degrees_: Named `Degrees` representing a coordinate in `degrees` with optional limits `low` and `high`.
          - pygeodesy.units.Lat_: Named `float` representing a latitude in `degrees` within limits `low` and `high`.
          - pygeodesy.units.Lon_: Named `float` representing a longitude in `degrees` within limits `low` and `high`.
        - pygeodesy.units.Lat: Named `float` representing a latitude in `degrees`.
        - pygeodesy.units.Lon: Named `float` representing a longitude in `degrees`.
      - pygeodesy.units.Degrees2: Named `float` representing a distance in `degrees squared`.
      - pygeodesy.units.Distance: Named `float` representing a distance, conventionally in `meter`.
      - pygeodesy.units.Feet: Named `float` representing a distance or length in `feet`.
      - pygeodesy.units.Float_: Named `float` with optional `low` and `high` limit.
        - pygeodesy.units.Distance_: Named `float` with optional `low` and `high` limits representing a distance, conventionally in `meter`.
        - pygeodesy.units.Epoch: Named `epoch` with optional `low` and `high` limits representing a fractional calendar year.
        - pygeodesy.units.FIx: A named Fractional Index, an `int` or `float` index into a `list` or `tuple` of `points`, typically.
        - pygeodesy.units.Height_: Named `float` with optional `low` and `high` limits representing a height, conventionally in `meter`.
        - pygeodesy.units.Meter2: Named `float` representing an area in `meter squared`.
        - pygeodesy.units.Meter3: Named `float` representing a volume in `meter cubed`.
        - pygeodesy.units.Meter_: Named `float` representing a distance or length in `meter`.
        - pygeodesy.units.Radians2: Named `float` representing a distance in `radians squared`.
        - pygeodesy.units.Radius_: Named `float` with optional `low` and `high` limits representing a radius, conventionally in `meter`.
        - pygeodesy.units.Scalar_: Named `float` with optional `low` and `high` limits representing a factor, fraction, scale, etc.
      - pygeodesy.units.Height: Named `float` representing a height, conventionally in `meter`.
        - pygeodesy.units.HeightX: Like Height, used to distinguish the interpolated height from an original Height at a clip intersection.
      - pygeodesy.units.Meter: Named `float` representing a distance or length in `meter`.
      - pygeodesy.units.Radians: Named `float` representing a coordinate in `radians`, optionally clipped.
        - pygeodesy.units.Bearing_: Named `float` representing a bearing in `radians` from compass `degrees` from (true) North.
        - pygeodesy.units.Lam: Named `float` representing a longitude in `radians`.
          - pygeodesy.units.Lamd: Named `float` representing a longitude in `radians` converted from `degrees`.
            - pygeodesy.deprecated.classes.Lam_: DEPRECATED on 2024.06.15, use class Lamd.
        - pygeodesy.angles.Lambertian: A `Lambertian` in `radians`.
        - pygeodesy.units.Phi: Named `float` representing a latitude in `radians`.
          - pygeodesy.units.Phid: Named `float` representing a latitude in `radians` converted from `degrees`.
            - pygeodesy.deprecated.classes.Phi_: DEPRECATED on 2024.06.15, use class Phid.
        - pygeodesy.units.Radians_: Named `float` representing a coordinate in `radians` with optional limits `low` and `high`.
      - pygeodesy.unitsBase.Radius: Named `float` representing a radius, conventionally in `meter`.
      - pygeodesy.units.Scalar: Named `float` representing a factor, fraction, scale, etc.
      - pygeodesy.units._EasNorBase: (INTERNAL) Easting and Northing base class.
        - pygeodesy.units.Easting: Named `float` representing an easting, conventionally in `meter`.
        - pygeodesy.units.Northing: Named `float` representing a northing, conventionally in `meter`.
  - int: int(x=0) -> int or long int(x, base=10) -> int or long
    - pygeodesy.unitsBase.Int: Named `int`.
      - pygeodesy.units.Bool: Named `bool`, a sub-class of `int` like Python's `bool`.
      - pygeodesy.epsg.Epsg: EPSG class, a named `int`.
      - pygeodesy.units.Int_: Named `int` with optional limits `low` and `high`.
        - pygeodesy.units.Number_: Named `int` representing a non-negative number.
        - pygeodesy.units.Precision_: Named `int` with optional `low` and `high` limits representing a precision.
      - pygeodesy.units.Zone: Named `int` representing a UTM/UPS zone number.
  - property: property(fget=None, fset=None, fdel=None, doc=None) -> property attribute
    - pygeodesy.props._PropertyBase: (INTERNAL) Base class for `P/property/_RO`.
      - pygeodesy.props.Property_RO
        - pygeodesy.props.Property
      - pygeodesy.props._property_RO___
        - pygeodesy.props.property_ROnce
        - pygeodesy.props.property_ROver
      - pygeodesy.props.property_RO
  - tuple: tuple() -> empty tuple tuple(iterable) -> tuple initialized from iterable's items
    - pygeodesy.named._NamedTuple: (INTERNAL) Base for named `tuple`s with both index and attribute name access to the items.
      - pygeodesy.albers.Albers7Tuple: 7-Tuple `(x, y, lat, lon, gamma, scale, datum)`, in `meter`, `meter`, `degrees90`, `degrees180`, `degrees360`, `scalar` and `Datum` where `(x, y)` is the projected, `(lat, lon)` the geodetic location, `gamma` the meridian convergence at point, the bearing of the y-axis measured clockwise from true North and `scale` is the azimuthal scale of the projection at point.
      - pygeodesy.karney.Area3Tuple: 3-Tuple `(number, perimeter, area)` with the `number` of points of the polygon or polyline, the `perimeter` in `meter` and the `area` in `meter` squared.
      - pygeodesy.ltpTuples.Attitude4Tuple: 4-Tuple `(alt, tilt, yaw, roll)` with `altitude` in (positive) `meter` and `tilt`, `yaw` and `roll` in `degrees` representing the attitude of a plane or camera.
      - pygeodesy.azimuthal.Azimuthal7Tuple: 7-Tuple `(x, y, lat, lon, azimuth, scale, datum)`, in `meter`, `meter`, `degrees90`, `degrees180`, compass `degrees`, `scalar` and `Datum` where `(x, y)` is the easting and northing of a projected point, `(lat, lon)` the geodetic location, `azimuth` the azimuth, clockwise from true North and `scale` is the projection scale, either `1 / reciprocal` or `1` or `-1` in the Equidistant case.
      - pygeodesy.namedTuples.Bearing2Tuple: 2-Tuple `(initial, final)` bearings, both in compass `degrees360`.
      - pygeodesy.namedTuples.Bounds2Tuple: 2-Tuple `(latlonSW, latlonNE)` with the bounds' lower-left and upper-right corner as `LatLon` instance.
      - pygeodesy.namedTuples.Bounds4Tuple: 4-Tuple `(latS, lonW, latN, lonE)` with the bounds' lower-left `(LatS, LowW)` and upper-right `(latN, lonE)` corner lat- and longitudes.
      - pygeodesy.ltpTuples.ChLVEN2Tuple: 2-Tuple `(E_LV95, N_LV95)` with falsed Swiss LV95 easting and norting in `meter (2_600_000, 1_200_000)` and origin at `Bern, Ch`.
      - pygeodesy.ltpTuples.ChLVYX2Tuple: 2-Tuple `(Y, X)` with unfalsed Swiss LV95 easting and norting in `meter`.
      - pygeodesy.ltpTuples.ChLVyx2Tuple: 2-Tuple `(y_LV03, x_LV03)` with falsed Swiss LV03 easting and norting in `meter (600_000, 200_000)` and origin at `Bern, Ch`.
      - pygeodesy.vector2d.Circin6Tuple: 6-Tuple `(radius, center, deltas, cA, cB, cC)` with the `radius`, the trilaterated `center` and contact points of the inscribed aka In- circle of a triangle.
      - pygeodesy.namedTuples.Circle4Tuple: 4-Tuple `(radius, height, lat, beta)` with the `radius` and `height` of a parallel circle of latitude at (geodetic) latitude `lat` and parametric (or reduced) auxiliary latitude `beta` on a biaxial ellipsoid.
      - pygeodesy.vector2d.Circum3Tuple: 3-Tuple `(radius, center, deltas)` with the `circumradius` and trilaterated `circumcenter` of the `circumcircle` through 3 points (aka {Meeus}' Type II circle) or the `radius` and `center` of the smallest Meeus' Type I circle.
      - pygeodesy.vector2d.Circum4Tuple: 4-Tuple `(radius, center, rank, residuals)` with `radius` and `center` of a sphere least-squares fitted through given points and the `rank` and `residuals` -if any- from numpy.linalg.lstsq.
      - pygeodesy.clipy.ClipCS4Tuple: 4-Tuple `(start, end, i, j)` for each edge of a clipped path with the `start` and `end` points (`LatLon`) of the portion of the edge inside or on the clip box and the indices `i` and `j` (`int`) of the edge start and end points in the original path.
      - pygeodesy.clipy.ClipFHP4Tuple: 4-Tuple `(lat, lon, height, clipid)` for each point of the clipFHP4 result with the `lat`-, `lon`gitude, `height` and `clipid` of the polygon or clip.
        - pygeodesy.clipy.ClipGH4Tuple: 4-Tuple `(lat, lon, height, clipid)` for each point of the clipGH4 result with the `lat`-, `lon`gitude, `height` and `clipid` of the polygon or clip.
      - pygeodesy.clipy.ClipLB6Tuple: 6-Tuple `(start, end, i, fi, fj, j)` for each edge of the clipped path with the `start` and `end` points (`LatLon`) of the portion of the edge inside or on the clip box, indices `i` and `j` (both `int`) of the original path edge start and end points and fractional indices `fi` and `fj` (both FIx) of the `start` and `end` points along the edge of the original path.
      - pygeodesy.clipy.ClipSH3Tuple: 3-Tuple `(start, end, original)` for each edge of a clipped polygon, the `start` and `end` points (`LatLon`) of the portion of the edge inside or on the clip region and `original` indicates whether the edge is part of the original polygon or part of the clip region (`bool`).
      - pygeodesy.resections.Collins5Tuple: 5-Tuple `(pointP, pointH, a, b, c)` with survey `pointP`, auxiliary `pointH`, each an instance of `pointA`'s (sub-)class and triangle sides `a`, `b` and `c` in `meter`, conventionally.
      - pygeodesy.triaxials.bases.Conformal5Tuple: 5-Tuple `(x, y, z, scale, llk)` with the easting `x` and northing `y` projection, `scale` or `NAN` but with `z=INT0` and kind `llk=LLK.CONFORMAL` always.
      - pygeodesy.ellipsoids.Curvature2Tuple: 2-Tuple `(meridional, prime_vertical)` of radii of curvature, both in `meter`, conventionally.
      - pygeodesy.namedTuples.Destination2Tuple: 2-Tuple `(destination, final)`, `destination` in `LatLon` and `final` bearing in compass `degrees360`.
      - pygeodesy.namedTuples.Destination3Tuple: 3-Tuple `(lat, lon, final)`, destination `lat`, `lon` in `degrees90` respectively `degrees180` and `final` bearing in compass `degrees360`.
      - pygeodesy.namedTuples.Distance2Tuple: 2-Tuple `(distance, initial)`, `distance` in `meter` and `initial` bearing in compass `degrees360`.
      - pygeodesy.namedTuples.Distance3Tuple: 3-Tuple `(distance, initial, final)`, `distance` in `meter` and `initial` and `final` bearing, both in compass `degrees360`.
      - pygeodesy.namedTuples.Distance4Tuple: 4-Tuple `(distance2, delta_lat, delta_lon, unroll_lon2)` with the distance in `degrees squared`, the latitudinal `delta_lat = lat2 - lat1`, the wrapped, unrolled and adjusted longitudinal `delta_lon = lon2 - lon1` and `unroll_lon2`, the unrolled or original `lon2`.
      - pygeodesy.fsums.DivMod2Tuple: 2-Tuple `(div, mod)` with the quotient `div` and remainder `mod` results of a `divmod` operation.
      - pygeodesy.namedTuples.EasNor2Tuple: 2-Tuple `(easting, northing)`, both in `meter`, conventionally.
      - pygeodesy.namedTuples.EasNor3Tuple: 3-Tuple `(easting, northing, height)`, all in `meter`, conventionally.
      - pygeodesy.css.EasNorAziRk4Tuple: 4-Tuple `(easting, northing, azimuth, reciprocal)` for the Cassini-Soldner location with `easting` and `northing` in `meters` and the `azimuth` of easting direction and `reciprocal` of azimuthal northing scale, both in `degrees`.
      - pygeodesy.css.EasNorAziRkEqu6Tuple: 6-Tuple `(easting, northing, azimuth, reciprocal, equatorarc, equatorazimuth)` for the Cassini-Soldner location with `easting` and `northing` in `meters` and the `azimuth` of easting direction, `reciprocal` of azimuthal northing scale, `equatorarc` and `equatorazimuth`, all in `degrees`.
      - pygeodesy.webmercator.EasNorRadius3Tuple: 3-Tuple `(easting, northing, radius)`, all in `meter`.
      - pygeodesy.ecef.Ecef9Tuple: 9-Tuple `(x, y, z, lat, lon, height, C, M, datum)` with geocentric `x`, `y` and `z` plus geodetic `lat`, `lon` and `height`, case `C` and optionally, rotation matrix `M` (EcefMatrix) and `datum`, with `lat` and `lon` in `degrees` and `x`, `y`, `z` and `height` in `meter`, conventionally.
      - pygeodesy.ecef.EcefMatrix: A rotation matrix known as East-North-Up (ENU) to ECEF.
      - pygeodesy.elevations.Elevation2Tuple: 2-Tuple `(elevation, data_source)` in `meter` and `str`.
      - pygeodesy.namedTuples.Ellipse5Tuple: 5-Tuple `(a, b, height, lat, beta)` with semi-axes `a` and `b` of a parallel ellipse of latitude at (geodetic) latitude `lat` and parametric (or reduced) auxiliary latitude `beta` of a triaxial ellipsoid.
      - pygeodesy.elliptic.Elliptic3Tuple: 3-Tuple `(sn, cn, dn)` all `scalar`.
      - pygeodesy.ltpTuples.Footprint5Tuple: 5-Tuple `(center, upperleft, upperight, loweright, lowerleft)` with the `center` and 4 corners of the local projection of a `Frustum`, each an Xyz4Tuple, XyzLocal, `LatLon`, etc.
      - pygeodesy.namedTuples.Forward4Tuple: 4-Tuple `(easting, northing, gamma, scale)` in `meter`, `meter`, meridian convergence `gamma` at point in `degrees` and the `scale` of projection at point `scalar`.
      - pygeodesy.frechet.Frechet6Tuple: 6-Tuple `(fd, fi1, fi2, r, n, units)` with the discrete Fréchet distance `fd`, fractional indices `fi1` and `fi2` as `FIx`, the recursion depth `r`, the number of distances computed `n` and the units class or name of the distance `units`.
      - pygeodesy.fsums.Fsum2Tuple: 2-Tuple `(fsum, residual)` with the precision running `fsum` and the `residual`, the sum of the remaining partials.
      - pygeodesy.elevations.GeoidHeight2Tuple: 2-Tuple `(height, model_name)`, geoid `height` in `meter` and `model_name` as `str`.
      - pygeodesy.geoids.GeoidHeight5Tuple: 5-Tuple `(lat, lon, egm84, egm96, egm2008)` for GeoidHeights.dat tests with the heights for 3 different EGM grids at `degrees90` and `degrees180` degrees (after converting `lon` from original `0 <= EasterLon <= 360`).
      - pygeodesy.hausdorff.Hausdorff6Tuple: 6-Tuple `(hd, i, j, mn, md, units)` with the Hausdorff distance `hd`, indices `i` and `j`, the total count `mn`, the `mean Hausdorff` distance `md` and the class or name of both distance `units`.
      - pygeodesy.geodesici.Intersect7Tuple: 7-Tuple `(A, B, sAB, aAB, c, kA, kB)` with `A` and `B` each a `LatLon` or LatLon4Tuple`(lat, lon, height, datum)` of the intersection on each geodesic line, the distance `sAB` in in `meter` and angular distance `aAB` in `degrees` between `A` and `B`, coincidence indicator `c` and segment indicators `kA` and `kB` all `int`, see XDict and method intersect7.
      - pygeodesy.namedTuples.Intersection3Tuple: 3-Tuple `(point, outside1, outside2)` of an intersection `point` and `outside1`, the position of the `point`, `-1` if before the start, `+1` if after the end and `0` if on or between the start and end point of the first line.
      - pygeodesy.geodesici.Intersectool5Tuple: 5-Tuple `(A, B, sAB, aAB, c)` with `A` and `B` the `Position` of the intersection on each geodesic line, the distance `sAB` between `A` and `B` in `meter`, the angular distance `aAB` in `degrees` and coincidence indicator `c` (`int`), see XDict.
        - pygeodesy.geodesici.Intersector5Tuple: 5-Tuple `(A, B, sAB, aAB, c)` with `A` and `B` the `Position` of the intersection on each geodesic line, the distance `sAB` between `A` and `B` in `meter`, angular distance `aAB` in `degrees` and coincidence indicator `c` (`int`), see XDict.
        - pygeodesy.geodesici.Middle5Tuple: 5-Tuple `(A, B, sMM, aMM, c)` with `A` and `B` the line segments including the mid-point location in `latM`, `lonM`, distance `s1M` in `meter` and angular distance `a1M` in `degrees`, the distance between both mid-points `sMM` in `meter` and angular distance `aMM` in `degrees` and coincidence indicator `c` (`int`).
      - pygeodesy.namedTuples.LatLon2Tuple: 2-Tuple `(lat, lon)` in `degrees90` and `degrees180`.
      - pygeodesy.namedTuples.LatLon3Tuple: 3-Tuple `(lat, lon, height)` in `degrees90`, `degrees180` and `meter`, conventionally.
        - pygeodesy.namedTuples.LatLon4Tuple: 4-Tuple `(lat, lon, height, datum)` in `degrees90`, `degrees180`, `meter` and Datum.
      - pygeodesy.css.LatLonAziRk4Tuple: 4-Tuple `(lat, lon, azimuth, reciprocal)`, all in `degrees` where `azimuth` is the azimuth of easting direction and `reciprocal` the reciprocal of azimuthal northing scale.
      - pygeodesy.namedTuples.LatLonDatum3Tuple: 3-Tuple `(lat, lon, datum)` in `degrees90`, `degrees180` and Datum.
        - pygeodesy.namedTuples.LatLonDatum5Tuple: 5-Tuple `(lat, lon, datum, gamma, scale)` in `degrees90`, `degrees180`, Datum, `degrees` and `float`.
      - pygeodesy.namedTuples.LatLonPrec3Tuple: 3-Tuple `(lat, lon, precision)` in `degrees`, `degrees` and `int`.
        - pygeodesy.namedTuples.LatLonPrec5Tuple: 5-Tuple `(lat, lon, precision, height, radius)` in `degrees`, `degrees`, `int` and `height` or `radius` in `meter` (or `None` if missing).
      - pygeodesy.ltpTuples.Local9Tuple: 9-Tuple `(x, y, z, lat, lon, height, ltp, ecef, M)` with local `x`, `y`, `z` all in `meter`, geodetic `lat`, `lon`, `height`, local tangent plane `ltp` (Ltp), `ecef` (Ecef9Tuple) with geocentric `x`, `y`, `z`, geodetic `lat`, `lon`, `height` and concatenated rotation matrix `M` (EcefMatrix) or `None`.
        - pygeodesy.ltpTuples.ChLV9Tuple: 9-Tuple `(Y, X, h_, lat, lon, height, ltp, ecef, M)` with unfalsed Swiss (Y, X, h_) coordinates and height, all in `meter`, `ltp` either a ChLV, ChLVa or ChLVe instance and `ecef` (EcefKarney at Bern, Ch), otherwise like Local9Tuple.
      - pygeodesy.vector2d.Meeus2Tuple: 2-Tuple `(radius, Type)` with `radius` and Meeus' `Type` of the smallest circle containing 3 points.
      - pygeodesy.mgrs.Mgrs4Tuple: 4-Tuple `(zone, EN, easting, northing)`, `zone` and grid tile `EN` as `str`, `easting` and `northing` in `meter`.
      - pygeodesy.mgrs.Mgrs6Tuple: 6-Tuple `(zone, EN, easting, northing, band, datum)`, with `zone`, grid tile `EN` and `band` as `str`, `easting` and `northing` in `meter` and `datum` a Datum.
      - pygeodesy.namedTuples.NearestOn2Tuple: 2-Tuple `(closest, fraction)` of the `closest` point on and `fraction` along a line (segment) between two points.
      - pygeodesy.namedTuples.NearestOn3Tuple: 3-Tuple `(closest, distance, angle)` of the `closest` point on the polygon, either a `LatLon` instance or a LatLon3Tuple`(lat, lon, height)` and the `distance` and `angle` to the `closest` point are in `meter` respectively compass `degrees360`.
      - pygeodesy.namedTuples.NearestOn6Tuple: 6-Tuple `(closest, distance, fi, j, start, end)` with the `closest` point, the `distance` in `meter`, conventionally and the `start` and `end` point of the path or polygon edge.
      - pygeodesy.namedTuples.NearestOn8Tuple: 8-Tuple `(closest, distance, fi, j, start, end, initial, final)`, like NearestOn6Tuple but extended with the `initial` and the `final` bearing at the reference respectively the `closest` point, both in compass `degrees`.
      - pygeodesy.namedTuples.PhiLam2Tuple: 2-Tuple `(phi, lam)` with latitude `phi` in `radians[PI_2]` and longitude `lam` in `radians[PI]`.
      - pygeodesy.namedTuples.PhiLam3Tuple: 3-Tuple `(phi, lam, height)` with latitude `phi` in `radians[PI_2]`, longitude `lam` in `radians[PI]` and `height` in `meter`.
      - pygeodesy.namedTuples.PhiLam4Tuple: 4-Tuple `(phi, lam, height, datum)` with latitude `phi` in `radians[PI_2]`, longitude `lam` in `radians[PI]`, `height` in `meter` and Datum.
      - pygeodesy.namedTuples.Point3Tuple: 3-Tuple `(x, y, ll)` in `meter`, `meter` and `LatLon`.
      - pygeodesy.namedTuples.Points2Tuple: 2-Tuple `(number, points)` with the `number` of points and -possible reduced- `list` or `tuple` of `points`.
      - pygeodesy.formy.Radical2Tuple: 2-Tuple `(ratio, xline)` of the radical `ratio` and radical `xline`, both `scalar` and `0.0 <= ratio <= 1.0`
      - pygeodesy.vector2d.Radii11Tuple: 11-Tuple `(rA, rB, rC, cR, rIn, riS, roS, a, b, c, s)` with the `Tangent` circle radii `rA`, `rB` and `rC`, the `circumradius` `cR`, the `Incircle` radius `rIn` aka `inradius`, the inner and outer Soddy circle radii `riS` and `roS`, the sides `a`, `b` and `c` and semi-perimeter `s` of a triangle, all in `meter` conventionally.
      - pygeodesy.geohash.Resolutions2Tuple: 2-Tuple `(res1, res2)` with the primary (longitudinal) and secondary (latitudinal) resolution, both in `degrees`.
      - pygeodesy.namedTuples.Reverse4Tuple: 4-Tuple `(lat, lon, gamma, scale)` with `lat`- and `lon`gitude in `degrees`, meridian convergence `gamma` at point in `degrees` and the `scale` of projection at point `scalar`.
      - pygeodesy.points.Shape2Tuple: 2-Tuple `(nrows, ncols)`, the number of rows and columns, both `int`.
      - pygeodesy.geohash.Sizes3Tuple: 3-Tuple `(height, width, radius)` with latitudinal `height`, longitudinal `width` and area `radius`, all in `meter`.
      - pygeodesy.vector2d.Soddy4Tuple: 4-Tuple `(radius, center, deltas, outer)` with `radius` and (trilaterated) `center` of the inner Soddy circle and the radius of the `outer` Soddy circle.
      - pygeodesy.resections.Survey3Tuple: 3-Tuple `(PA, PB, PC)` with distance from survey point `P` to each of the triangle corners `A`, `B` and `C` in `meter`, conventionally.
      - pygeodesy.trf.TRFXform7Tuple: 7-Tuple `(tx, ty, tz, s, sx, sy, sz)` of conversion parameters with translations `tx`, `ty` and `tz` in `milli-meter`, scale `s` in `ppB` and rotations `sx`, `sy` and `sz` in `milli-arc-seconds`.
      - pygeodesy.resections.Tienstra7Tuple: 7-Tuple `(pointP, A, B, C, a, b, c)` with survey `pointP`, interior triangle angles `A`, `B` and `C` in `degrees` and triangle sides `a`, `b` and `c` in `meter`, conventionally.
      - pygeodesy.resections.TriAngle5Tuple: 5-Tuple `(radA, radB, radC, rIn, area)` with the interior angles at triangle corners `A`, `B` and `C` in `radians`, the `InCircle` radius `rIn` aka `inradius` in `meter` and the triangle `area` in `meter` squared, conventionally.
      - pygeodesy.resections.TriSide2Tuple: 2-Tuple `(a, radA)` with triangle side `a` in `meter`, conventionally and angle `radA` at the opposite triangle corner in `radians`.
      - pygeodesy.resections.TriSide4Tuple: 4-Tuple `(a, b, radC, d)` with interior angle `radC` at triangle corner `C` in `radians`with the length of triangle sides `a` and `b` and with triangle height `d` perpendicular to triangle side `c`, in the same units as triangle sides `a` and `b`.
      - pygeodesy.namedTuples.Triangle7Tuple: 7-Tuple `(A, a, B, b, C, c, area)` with interior angles `A`, `B` and `C` in `degrees`, spherical sides `a`, `b` and `c` in `meter` conventionally and the `area` of a (spherical) triangle in square `meter` conventionally.
      - pygeodesy.namedTuples.Triangle8Tuple: 8-Tuple `(A, a, B, b, C, c, D, E)` with interior angles `A`, `B` and `C`, spherical sides `a`, `b` and `c`, the spherical deficit `D` and the spherical excess `E` of a (spherical) triangle, all in `radians`.
      - pygeodesy.vector2d.Triaxum5Tuple: 5-Tuple `(a, b, c, rank, residuals)` with the (unordered) triaxial radii `a`, `b` and `c` of an ellipsoid least-squares fitted through given points and the `rank` and `residuals` -if any- from numpy.linalg.lstsq.
      - pygeodesy.namedTuples.Trilaterate5Tuple: 5-Tuple `(min, minPoint, max, maxPoint, n)` with `min` and `max` in `meter`, the corresponding trilaterated `minPoint` and `maxPoint` as `LatLon` and the number `n`.
      - pygeodesy.namedTuples.UtmUps2Tuple: 2-Tuple `(zone, hemipole)` as `int` and `str`, where `zone` is `1..60` for UTM or `0` for UPS and `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole.
      - pygeodesy.namedTuples.UtmUps5Tuple: 5-Tuple `(zone, hemipole, easting, northing, band)` as `int`, `str`, `meter`, `meter` and `band` letter, where `zone` is `1..60` for UTM or `0` for UPS, `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole and `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'`.
      - pygeodesy.namedTuples.UtmUps8Tuple: 8-Tuple `(zone, hemipole, easting, northing, band, datum, gamma, scale)` as `int`, `str`, `meter`, `meter`, `band` letter, `Datum`, `degrees` and `scalar`, where `zone` is `1..60` for UTM or `0` for UPS, `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole and `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'`.
      - pygeodesy.namedTuples.UtmUpsLatLon5Tuple: 5-Tuple `(zone, band, hemipole, lat, lon)` as `int`, `str`, `str`, `degrees90` and `degrees180`, where `zone` is `1..60` for UTM or `0` for UPS, `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'` and `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole.
      - pygeodesy.ltpTuples.Uvw3Tuple: 3-Tuple `(u, v, w)`, in `meter`.
      - pygeodesy.namedTuples.Vector2Tuple: 2-Tuple `(x, y)` of (geocentric) components, each in `meter` or the same `units`.
      - pygeodesy.namedTuples.Vector3Tuple: 3-Tuple `(x, y, z)` of (geocentric) components, all in `meter` or the same `units`.
      - pygeodesy.namedTuples.Vector4Tuple: 4-Tuple `(x, y, z, h)` of (geocentric) components, all in `meter` or the same `units`.
        - pygeodesy.triaxials.triaxial3.Cartesian5Tuple: 5-Tuple `(x, y, z, h, llk)` with cartesian `x`, `y` and `z` coordinates on and height `h` above or below the triaxial's surface and kind `llk` set to the original `LLK` or `None`.
      - pygeodesy.ltpTuples._Abc4Tuple: (INTERNAL) Base class for `Aer4Tuple`, `Enu4Tuple`, `Ned4Tuple` and `Xyz4Tuple`.
        - pygeodesy.ltpTuples.Aer4Tuple: 4-Tuple `(azimuth, elevation, slantrange, ltp)`, all in `meter` except `ltp`.
        - pygeodesy.ltpTuples.Enu4Tuple: 4-Tuple `(east, north, up, ltp)`, in `meter` except `ltp`.
        - pygeodesy.ltpTuples.Ned4Tuple: 4-Tuple `(north, east, down, ltp)`, all in `meter` except `ltp`.
        - pygeodesy.ltpTuples.Xyz4Tuple: 4-Tuple `(x, y, z, ltp)`, all in `meter` except `ltp`.
      - pygeodesy.angles._Ang3Tuple: (INTERNAL) Methods `.toDegrees`, `.toLambertian`, `.toRadians` and `.toUnit`.
        - pygeodesy.triaxials.triaxial3.BetOmgAlp5Tuple: 5-Tuple `(bet, omg, alp, h, llk)` with ellipsoidal lat- `bet`, longitude `omg` and azimuth `alp`, all in Angles on and height `h` off the triaxial's surface and kind `llk` set to `LLK.ELLIPSOIDAL`.
        - pygeodesy.triaxials.conformal3.BetOmgGam5Tuple: 5-Tuple `(bet, omg, gam, scale, llk)` with ellipsoidal lat- `bet`, longitude `omg` and meridian convergence `gam` all Angles, `scale` and kind `llk` set to `LLK.CONFORMAL`.
        - pygeodesy.triaxials.triaxial3.PhiLamZet5Tuple: 5-Tuple `(phi, lam, zet, h, llk)` with trixial lat- lat- `phi`, longitude `lam` and azimuth `zet`, all in Angles on and height `h` off the triaxial's surface and kind `llk` set to an `LLK`.
      - pygeodesy.deprecated.classes._Deprecated_NamedTuple: DEPRECATED, `_NamedTuple` base.
        - pygeodesy.deprecated.classes.ClipCS3Tuple: DEPRECATED, see DEPRECATED function pygeodesy.deprecated.clipCS3.
        - pygeodesy.deprecated.classes.EasNorExact4Tuple: DEPRECATED, use class Forward4Tuple, item `gamma` for `convergence`.
        - pygeodesy.deprecated.classes.LatLonExact4Tuple: DEPRECATED, use class Reverse4Tuple, item `gamma` for `convergence`.
        - pygeodesy.deprecated.classes.NearestOn4Tuple: DEPRECATED on 2023.10.10, see methods RhumbLine.nearestOn4 and RhumbLineAux.nearestOn4.
        - pygeodesy.deprecated.classes.Ned3Tuple: DEPRECATED, use class Ned4Tuple, ignoring item `ltp`.
        - pygeodesy.deprecated.classes.Rhumb7Tuple: DEPRECATED, use class Rhumb8Tuple, ignoring item `a12`.
        - pygeodesy.deprecated.classes.RhumbOrder2Tuple: DEPRECATED, see deprecated method Rhumb.orders.
        - pygeodesy.deprecated.classes.Transform7Tuple: DEPRECATED on 2024.02.02, use class TRFXform7Tuple, without keyword arguments.
        - pygeodesy.deprecated.classes.TriAngle4Tuple: DEPRECATED on 2023.09.14, use class TriAngle5Tuple, ignoring item `area`.
        - pygeodesy.deprecated.classes.UtmUps4Tuple: DEPRECATED and OBSOLETE, expect a UtmUps5Tuple from method `pygeodesy.Mgrs.toUtm(utm=None)`.
      - pygeodesy.karney._GTuple: (INTERNAL) Helper.
        - pygeodesy.karney.Direct9Tuple: 9-Tuple `(a12, lat2, lon2, azi2, s12, m12, M12, M21, S12)` with arc length `a12`, angles `lat2`, `lon2` and azimuth `azi2` in `degrees`, distance `s12` and reduced length `m12` in `meter` and area `S12` in `meter` squared.
        - pygeodesy.geod3solve.Geod3Solve8Tuple: 8-Tuple `(bet1, omg1, alp1, bet2, omg2, alp2, s12, a12)` with `ellipsoidal` latitudes `bet1` and `bet2`, `ellipsoidal` longitudes `omg1` and `omg2`, forward azimuths `alp1` and `alp2` in bearings from North, distance `s12` in `meter`, conventionally and approximate arc length `a12` in degrees, see Geod3Solve.
        - pygeodesy.geodsolve.GeodSolve12Tuple: 12-Tuple `(lat1, lon1, azi1, lat2, lon2, azi2, s12, a12, m12, M12, M21, S12)` with angles `lat1`, `lon1`, `azi1`, `lat2`, `lon2` and `azi2` and arc `a12` all in `degrees`, initial `azi1` and final `azi2` forward azimuths in bearings, degrees from North, distance `s12` and reduced length `m12` in `meter`, area `S12` in `meter` squared and geodesic scale factors `M12` and `M21`, both `scalar`, see GeodSolve.
        - pygeodesy.karney.Inverse10Tuple: 10-Tuple `(a12, s12, salp1, calp1, salp2, calp2, m12, M12, M21, S12)` with arc length `a12` in `degrees`, distance `s12` and reduced length `m12` in `meter`, area `S12` in `meter` squared and the sines `salp1`, `salp2` and cosines `calp1`, `calp2` of the initial `1` and final `2` (forward) azimuths.
        - pygeodesy.karney.Rhumb8Tuple: 8-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12, a12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12`, the area `S12` under the rhumb line and the angular distance `a12` between both points.
          - pygeodesy.rhumb.solve.RhumbSolve7Tuple: 7-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12` and the area `S12` under the rhumb line between both points.
        - pygeodesy.deprecated.classes.RhumbOrder2Tuple: DEPRECATED, see deprecated method Rhumb.orders.
      - pygeodesy.namedTuples._NamedTupleTo: (INTERNAL) Base for `-.toDegrees`, `-.toRadians`.
        - pygeodesy.cartesianBase.RadiusThetaPhi3Tuple: 3-Tuple `(r, theta, phi)` with radial distance `r` in `meter`, inclination `theta` (with respect to the positive z-axis) and azimuthal angle `phi` in Degrees or Radians representing a spherical, polar position.
        - pygeodesy.triaxials.triaxial5._NamedTupleToX: (INTERNAL) Base class for BetaOmega2Tuple, BetaOmega3Tuple and Conformal2Tuple.
          - pygeodesy.triaxials.triaxial5.BetaOmega2Tuple: 2-Tuple `(beta, omega)` with ellipsoidal lat- and longitude `beta` and `omega` both in Radians (or Degrees).
          - pygeodesy.triaxials.triaxial5.BetaOmega3Tuple: 3-Tuple `(beta, omega, height)` with ellipsoidal lat- and longitude `beta` and `omega` both in Radians (or Degrees) and the `height`, rather the (signed) distance to the triaxial's surface (measured along the radial line to the triaxial's center) in `meter`, conventionally.
          - pygeodesy.triaxials.triaxial5.Conformal2Tuple: 2-Tuple `(x, y)` with a Jacobi Conformal `x` and `y` projection, both in Radians (or Degrees).
            - pygeodesy.deprecated.classes.Jacobi2Tuple: DEPRECATED on 25.11.11, use class Conformal2Tuple.
      - pygeodesy.ellipsoids.a_f2Tuple: 2-Tuple `(a, f)` specifying an ellipsoid by equatorial radius `a` in `meter` and scalar flattening `f`.
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - abc.ABCMeta: Metaclass for defining Abstract Base Classes (ABCs).